/* ------------------------------------------------------------------

File:		AviationWeather.js
Abstract:	main file
Version:	1.2.13 (02/12/2012)
Author:		Pascal Dreer

------------------------------------------------------------------ */

// 1.2.13 fixed TAF bug


var timer = null;					// communication vars
var xml_request;
var xml_request_version;
var firstConnection;
var fetchInProgress = false;
var updateTime = new Date();

var actData = [];					// main data containers
var	actDataDisplay = [];
var lastData = [];

var metarTxt = "";					// main parsing var

var presets = [];					// global preset array with obj
presets = new Array(5);	

var currentPreset = 0;				// 0 = no preset selected
	
									// prefs
var dataSource = 1;
var showAll = false;					// show all station in raw mode
var showRMK = false;					// nwwsmetar remarks
var showLocalTime = false;				// local time only (instead of UTC)
var showRawFormat = false;				// nicer data formatting
var showCalc = false;					// show calculations (fzlvl, pa, da)
var displayFormat = 1;					// use raw format
var keepPrefs = false;					// do not remove prefs when closing widget
var keepPastData = false;				// fetch also past data (METAR only)
var keepPastDataHrs = 2;				// default is 2 hours
var username = "";

var presetsDirty = true;			// display vars
var toggleTaf = false;
var defaultWinHeight = 230;	

var gVScrollArea, gVScrollbar;
var	gDoneButton;

var debug = "";

var kinHg2mb = 33.8639;				// constant values for conversions
var kmb2inHg = 0.0295300;
var kft2m = 0.3048;
var km2ft = 3.2808399;


if (window.widget) {
	widget.onremove = onremove;
	widget.onhide = onhide;
	widget.onshow = onshow;
}


function getLocalizedString (key)
{
	try {
		var ret = localizedStrings[key];
		if (ret == undefined)
			ret = key;
		return ret;
	} catch (ex) {}

	return key;
}



isIE = false;
function getElementTextNS(prefix, local, parentElem, index) {
    var result = "";
    if (prefix && isIE) {
        // IE/Windows way of handling namespaces
        result = parentElem.getElementsByTagName(prefix + ":" + local)[index];
    } else {
        // the namespace versions of this method
        // (getElementsByTagNameNS()) operate
        // differently in Safari and Mozilla, but both
        // return value with just local name, provided
        // there aren't conflicts with non-namespace element
        // names
        result = parentElem.getElementsByTagName(local)[index];
    }
    if (result) {
        if (result.childNodes.length > 1) {
            return result.childNodes[1].nodeValue;
        } else {
			if (result.firstChild)
				return result.firstChild.nodeValue;
			else
				return getLocalizedString("No Data Available.");
        }
    } else {
        return "n/a";
    }
}


// -----------------------------------------------------------
// MAIN HANDLER
// -----------------------------------------------------------

function onshow() 
{	
	var currentTime = new Date();
	if (currentTime.getTime() < (updateTime.getTime() + 20000) && everBeenCalled)				// do not update within 20 sec.
		return;

	if (timer != null) {
		clearInterval(timer);
		timer = null;
	}
		
	timer = setInterval("getAllData();",600000);			// and then 10min (600000) afterwards
	
	presetsDirty = true;									// update only when stations have changed
	getAllData();
	everBeenCalled = true;
}


function onhide() 
{
	if (timer != null) {
		clearInterval(timer);
		timer = null;
	}
	
	updateTime = new Date();
}


function onremove()
{
	if (window.widget) {
		var savedKeepPrefs = keepPrefs;
		keepPrefs = false;							// remove prefs with widget-id in any case
		widget.setPreferenceForKey(null,createkey("stn1-icao"));
		widget.setPreferenceForKey(null,createkey("stn1-name"));
		widget.setPreferenceForKey(null,createkey("show-all"));
		widget.setPreferenceForKey(null,createkey("data-source"));
		widget.setPreferenceForKey(null,createkey("display-format"));
		widget.setPreferenceForKey(null,createkey("show-remarks"));
		widget.setPreferenceForKey(null,createkey("show-time"));
		widget.setPreferenceForKey(null,createkey("show-rawFormat"));
		widget.setPreferenceForKey(null,createkey("metric-format"));
		widget.setPreferenceForKey(null,createkey("show-keepPrefs"));
		widget.setPreferenceForKey(null,createkey("show-keepPastData"));

		for (var i=1;i<5;i++) {
			widget.setPreferenceForKey(null,createkey("preset" + i + "-icao"));
			widget.setPreferenceForKey(null,createkey("preset" + i + "-name"));
			widget.setPreferenceForKey(null,createkey("preset" + i + "-latitude"));
			widget.setPreferenceForKey(null,createkey("preset" + i + "-longitude"));
			widget.setPreferenceForKey(null,createkey("preset" + i + "-timezone"));
			widget.setPreferenceForKey(null,createkey("preset" + i + "-summertime"));
			widget.setPreferenceForKey(null,createkey("preset" + i + "-elevation"));
		}
		
		keepPrefs = savedKeepPrefs;
		
		if (!keepPrefs) {
			widget.setPreferenceForKey(null,"stn1-icao");
			widget.setPreferenceForKey(null,"stn1-name");
			widget.setPreferenceForKey(null,"show-all");
			widget.setPreferenceForKey(null,"data-source");
			widget.setPreferenceForKey(null,"display-format");
			widget.setPreferenceForKey(null,"show-remarks");
			widget.setPreferenceForKey(null,"show-time");
			widget.setPreferenceForKey(null,"show-rawFormat");
			widget.setPreferenceForKey(null,"metric-format");
			widget.setPreferenceForKey(null,"show-keepPrefs");
			widget.setPreferenceForKey(null,"show-keepPastData");

			for (var i=1;i<5;i++) {
				widget.setPreferenceForKey(null,"preset" + i + "-icao");
				widget.setPreferenceForKey(null,"preset" + i + "-name");
				widget.setPreferenceForKey(null,"preset" + i + "-latitude");
				widget.setPreferenceForKey(null,"preset" + i + "-longitude");
				widget.setPreferenceForKey(null,"preset" + i + "-timezone");
				widget.setPreferenceForKey(null,"preset" + i + "-summertime");
				widget.setPreferenceForKey(null,"preset" + i + "-elevation");
			}
		}
	}
}



// -----------------------------------------------------------
// DATA FORMAT HANDLING
// -----------------------------------------------------------

function scanAndInsertTag(tag,inText) 
{
	var formattedText = inText;
	var outText = "";
	var i = 0;
			
	do {
		tmppos = formattedText.indexOf(tag,i);
		if (tmppos >= 0) {
			outText = formattedText.substring(0,tmppos) + "<br>" + formattedText.substring(tmppos,formattedText.length);
			formattedText = outText;
			i = tmppos + 5;
		}
	} while (tmppos >= 0);
	outText = formattedText;

	return outText;
}



function formatRawData(rawData,doFormat)
{
	if (rawData == "")
		return getLocalizedString("No Data Available.");

	if (showRawFormat && doFormat) {
		var savedIcao = rawData.substring(0,rawData.indexOf(" ")+1);
		var tmpstr = rawData.substring(rawData.indexOf(" ")+1,rawData.length);	// remove icao code
	
		var formatText = "";
		
		formatText = scanAndInsertTag("TEMPO",tmpstr);
		tmpstr = formatText;
		formatText = scanAndInsertTag("BECMG",tmpstr);
		tmpstr = formatText;
		formatText = scanAndInsertTag("FM",tmpstr);
		tmpstr = formatText;
		formatText = scanAndInsertTag("PROB",tmpstr);
		tmpstr = savedIcao + formatText;
	}
	else
		var tmpstr = rawData;
	
	return tmpstr;
}



function parseForDate(rawData)
{
	if (rawData == "")
		return null;
	
	var dateObj = new Date();
		
	var tmpstr = rawData.substring(rawData.indexOf(" ")+1,rawData.length);
	var tmpdate = tmpstr.substring(0,tmpstr.indexOf(" "));
	
	
	if (tmpdate.charAt(6) == 'Z') {
		dateObj.setDate(Math.floor(tmpdate.substring(0,2)));
		dateObj.setHours(Math.floor(tmpdate.substring(2,4)));
		dateObj.setMinutes(Math.floor(tmpdate.substring(4,6)));
		var timeTmp = dateObj.getTime() - (dateObj.getTimezoneOffset() * 60000);
		dateObj.setTime(timeTmp);
		
		return dateObj;
	}
	else {
		if (tmpdate.length == 6) {
			dateObj.setDate(Math.floor(tmpdate.substring(0,2)));
			dateObj.setHours(Math.floor(tmpdate.substring(2,4)));
			dateObj.setMinutes(Math.floor(tmpdate.substring(4,6)));
			return dateObj;
		}
		else {
			return null;
		}
	}
}


function calcFreezingLevel(obj)
{
	var fzlvl = 0;

	if (parseInt(obj.gTemperature,10) > 0)
		fzlvl = parseInt(obj.elevation,10) + Math.floor(parseInt(obj.gTemperature,10) / 0.65 * 100);
	else 
		return "-";

	if (metricFormat >= 4)
		return fzlvl + " " + getLocalizedString("meter");
	else
		return Math.round(fzlvl * km2ft) + " " + getLocalizedString("feet");
}


// formula by NWS El Paso
function calcStationPressure(elev,pressure)
{
	// elev in meter; pressure in inHg; returns inHg
	sp = pressure * Math.pow((288 - (0.0065 * parseInt(elev,10))) / 288,5.2561);

	return sp;
}

//var kinHg2mb = 33.8639;				// constant values for conversions
//var kmb2inHg = 0.0295300;


// formula by NWS El Paso
function calcPressureAltitude(obj)
{
	if (isNaN(parseFloat(obj.gPressure)))		
		return "-";
		
	if (obj.gPressure.indexOf("hPa") > 0)
		var p_mb = calcStationPressure(obj.elevation,parseInt(obj.gPressure,10) * kmb2inHg) * kinHg2mb;
	else 
		var p_mb = calcStationPressure(obj.elevation,parseFloat(obj.gPressure)) * kinHg2mb;

	var pa = 0;
	pa = (1 - Math.pow((p_mb / 1013.25),0.190284)) * 145366.45;
	
	if (metricFormat >= 4)
		return Math.round(pa * kft2m) + " " + getLocalizedString("meter");
	else
		return Math.round(pa) + " " + getLocalizedString("feet");
}


// formula by NWS El Paso
function calcDensityAltitude(obj)
{
	if (obj.gPressure.indexOf("hPa") > 0) {
		var p_mb = calcStationPressure(obj.elevation,parseInt(obj.gPressure,10) * kmb2inHg) * kinHg2mb;
		var p_hg = calcStationPressure(obj.elevation,parseInt(obj.gPressure,10) * kmb2inHg);
	}
	else {
		var p_mb = calcStationPressure(obj.elevation,parseFloat(obj.gPressure)) * kinHg2mb;
		var p_hg = calcStationPressure(obj.elevation,parseFloat(obj.gPressure));
	}
	
	var dp_c = parseInt(obj.gDewpoint,10);
	var tp_k = parseInt(obj.gTemperature,10) + 273.15;

	if (isNaN(p_mb) || isNaN(dp_c) || isNaN(tp_k))
		return "-";

	var val_e = 6.11 * Math.pow(10,(7.5 * dp_c / (237.7 + dp_c)));
	var val_tv = tp_k / (1 - (val_e / p_mb) * (1 - 0.622));
	var val_tvr = (1.8 * (val_tv - 273.15) + 32) + 459.69;
	var da = 145366 * (1 - (Math.pow((17.326 * p_hg) / val_tvr,0.235)));
	
	if (metricFormat >= 4)
		return Math.round(da * kft2m) + " " + getLocalizedString("meter");
	else
		return Math.round(da) + " " + getLocalizedString("feet");
}


function buildSunriseSunset(obj,presetNo)
{
	if (obj) {									// show stations daylight
		var today = new Date();
		calculateSunrise(today,obj.latitude,obj.longitude,true);
		if (showLocalTime) {
			var dateLT = convertToLocalTime(today,presetNo);
			var hrs = dateLT.getHours();
			var mins = dateLT.getMinutes();
		}
		else {
			var hrs = today.getUTCHours();
			var mins = today.getUTCMinutes();
		}
		
		if ((metricFormat >= 3) || (!showLocalTime))
			var sunrise = ((hrs < 10) ? "0" + hrs : hrs) + ":" + ((mins < 10) ? "0" + mins : mins);
		else {
			if (hrs > 12)
				hrs = hrs - 12;
			var sunrise = ((hrs < 10) ? "0" + hrs : hrs) + ":" + ((mins < 10) ? "0" + mins : mins) + " AM";
		}
		
		calculateSunrise(today,obj.latitude,obj.longitude,false);
		if (showLocalTime) {
			var dateLT = convertToLocalTime(today,presetNo);
			var hrs = dateLT.getHours();
			var mins = dateLT.getMinutes();
			var utcText = " LT";
		}
		else {
			var hrs = today.getUTCHours();
			var mins = today.getUTCMinutes();
			var utcText = " UTC";
		}
		 
		if ((metricFormat >= 3) || (!showLocalTime))
			var sunset = ((hrs < 10) ? "0" + hrs : hrs) + ":" + ((mins < 10) ? "0" + mins : mins);
		else {
			if (hrs > 12)
				hrs = hrs - 12;
			var sunset = ((hrs < 10) ? "0" + hrs : hrs) + ":" + ((mins < 10) ? "0" + mins : mins) + " PM";
		}
			
		obj.sunrise = sunrise;
		obj.sunset = sunset;
	}
}


function parseForTranslation(rawData,obj,metar)
{
	var translatedText = "";
	if (rawData == "") {
		return translatedText;
	}
		
		
	metarTxt = "<table id='plate' border='0' width='265' cellpadding='1' cellspacing='0'>";			// was 285

	if (metar) {										// show daylight in METAR report only
		if (showRMK) {
			if (showLocalTime)
				var utcText = " LT";
			else
				var utcText = " UTC";

			var sunriseSunset = "<tr valign='top'><td>" + getLocalizedString("Daylight: ") + "</td><td>" + 
								getLocalizedString("Sunrise ") + obj.sunrise + ", " + getLocalizedString("Sunset ") + obj.sunset + utcText + "</td></tr>";
		}
	}
	if (rawData.indexOf("NIL") >= 0 && rawData.length <= 30) {
		if (showRMK && metar)
			metarTxt = metarTxt + sunriseSunset;
		metarTxt = metarTxt + "<tr valign='top'><td colspan=2>" + getLocalizedString("No Data Available.") + " (NIL)" + "</td></tr>";
		metarTxt = metarTxt + "</table>";
		return metarTxt;
	}
	
	var tmpstr = rawData.substring(rawData.indexOf(" ")+1,rawData.length);	// remove icao code
	if (showRMK && metar)
		metarTxt = metarTxt + sunriseSunset;
	parseMetarString(tmpstr,obj,metar);					// writes directly into metarTxt
	
	if (metar && showCalc && obj.gPressure != 0 && obj.gTemperature != 0) {						// do calculations in METAR report only
		obj.fl = calcFreezingLevel(obj);
		obj.pa = calcPressureAltitude(obj);
		obj.da = calcDensityAltitude(obj);
		
		if (metricFormat >= 4)
			var elev = obj.elevation + " " + getLocalizedString("meter");
		else
			var elev = Math.round(obj.elevation * km2ft) + " " + getLocalizedString("feet");
	
		metarTxt = metarTxt + "<tr valign='top'><td><span class='calculationText'>" + getLocalizedString("Calculations ") + "</span></td><td><table id='altitude' border='0' cellpadding='0' cellspacing='0'>";

		metarTxt = metarTxt + "<tr valign='top'><td><span class='calculationText'>"  + getLocalizedString("Station elevation") + "</span></td><td align='right'>&nbsp;<span class='calculationText'> " + elev + "</span>" + "</td></tr>";

		metarTxt = metarTxt + "<tr valign='top'><td>" + getLocalizedString("Pressure altitude: ") + "</td><td align='right'>&nbsp;" + obj.pa + "</td></tr>";
		metarTxt = metarTxt + "<tr valign='top'><td>" + getLocalizedString("Density altitude: ") + "</td><td align='right'>&nbsp;" + obj.da + "</td></tr>";
		metarTxt = metarTxt + "<tr valign='top'><td>" + getLocalizedString("Freezing level (ISA): ") + "</td><td align='right'>&nbsp;" + obj.fl + "</td></tr>";
		
		metarTxt = metarTxt + "</table></td></tr>";
	}
	
	metarTxt = metarTxt + "</table>";
	translatedText = metarTxt;
		
	return translatedText;
}


function parseNWSData(presetNo) 
{
	for (var i=0;i<actData.length;i++) {
		
		if (presetNo > 0 && presetNo != i)
			continue;
	
		var obj = new Object();
		
		obj.gTemperature = 0;
		obj.gDewpoint = 0;
		obj.gHumidity = 0;
		obj.gWindDir = 0;
		obj.gWindSpeed = 0;
		obj.gWindGusts = 0;
		obj.gWindVar1 = 0;
		obj.gWindVar2 = 0;
		obj.gPressure = 0;
		obj.gPressureTrend = "";
		obj.gWeather0 = "";
		obj.gWeather1 = "";
		obj.gWeather2 = "";
		obj.gCloud1 = "";
		obj.gCloud2 = "";
		obj.gCloud3 = "";
		obj.gVisibility = "";
		

		obj.icao = actData[i].icao;
		obj.name = presets[i].name;
		obj.latitude = presets[i].latitude;
		obj.longitude = presets[i].longitude;
		obj.timezone = presets[i].timezone;
		obj.summertime = presets[i].summertime;
		obj.elevation = presets[i].elevation;
		obj.preset = i;

		obj.sunrise = "";
		obj.sunset = "";
		buildSunriseSunset(obj,i);
						
		obj.tDate = parseForDate(actData[i].taf);
		obj.tTextRaw = formatRawData(actData[i].taf,true);
		obj.tTextTrans = parseForTranslation(actData[i].taf,obj,false);
		obj.mDate = parseForDate(actData[i].metar);
		obj.mTextRaw = formatRawData(actData[i].metar,false);
		obj.mTextTrans = parseForTranslation(actData[i].metar,obj,true);
		obj.flightRules = parseFlightRules(actData[i].metar);
		
		if (displayFormat == 3)
			parseMetarGraphical(actData[i].metar,obj);

		actDataDisplay[i] = obj;
//		actDataDisplay.push(obj);
	}
}


function loadNWSData(responseStr) 
{	
	var curDate = new Date();
	for (var i=0;i<5;i++)												// get all presets
		if (presets[i].icao.length == 4) {
			var obj = new Object();
			obj.date = curDate;
			obj.icao = presets[i].icao;
			obj.source = 1;
			
			var tmpposA = responseStr.indexOf(">" + presets[i].icao);	// get latest METAR first
			if (tmpposA == -1) {
				obj.metar = "";
				obj.metarPast = "";
			}
			else {
				tmpposA = tmpposA + 5;
				var tmpposB = responseStr.indexOf("<",tmpposA);
				if (tmpposB == -1) {
					obj.metar = "";
					obj.metarPast = "";
					obj.taf = "";
					obj.err = 2;										// something's messed up with nws data structure
					actData.push(obj);
					continue;
				}
				var metar = responseStr.substring(tmpposA-4,tmpposB);
				obj.metar = metar;
				obj.metarPast = "";
			}
			
			if (keepPastData && obj.metar != "") {						// get additional past METARs
				obj.metarPast = new Array();
				
				obj.metarPast.push(metar);								// put current METAR first
			
				while (true) {				
					tmpposA = responseStr.indexOf(">" + presets[i].icao,tmpposB);		
					if (tmpposA == -1) {
						break;
					}
					else {
						tmpposA = tmpposA + 5;
						tmpposB = responseStr.indexOf("<",tmpposA);
						if (tmpposB == -1) {
							obj.metarPast = "";
							obj.taf = "";
							obj.err = 2;								// something's messed up with nws data structure
							actData.push(obj);
							continue;
						}
						metar = responseStr.substring(tmpposA-4,tmpposB);
						obj.metarPast.push(metar);
					}
				}
				obj.metarPastPos = 0;
				
				if (obj.metar.indexOf("NIL") > 0 && obj.metarPast.length > 1) {			// use next METAR if latest is NIL
					obj.metarPastPos = 1;
					obj.metar = obj.metarPast[1];
				}
			}
									
													
			tmpposA = responseStr.indexOf(">\n" + presets[i].icao);		// then, get TAFs
			if (tmpposA == -1) {
				tmpposA = responseStr.indexOf(">\nTAF " + presets[i].icao);		// then, get TAFs
				if (tmpposA == -1) {
					obj.taf = "";											// taf is not there
					obj.err = 0;
					actData.push(obj);
					continue;
				}
				else
					tmpposA += 4;
			}
			tmpposA = tmpposA + 5;
			tmpposB = responseStr.indexOf("<",tmpposA);
			if (tmpposB == -1) {
				obj.taf = "";
				obj.err = 2;											// something's messed up with nws data structure
				actData.push(obj);
				continue;
			}
			var taf = responseStr.substring(tmpposA-3,tmpposB);			// everything went fine
			obj.taf = taf;
			obj.err = 0;
			actData.push(obj);
		}
		else {															// create empty object instead
			var obj = new Object();
			obj.date = curDate;
			obj.icao = "";
			obj.source = 1;
			obj.metar = "";
			obj.metarPast = "";
			obj.taf = "";
			obj.err = 99;
			actData.push(obj);
		}
}


function loadMyMetarData(resXML) 
{
	if (!resXML)
		return -1;

    var groups = resXML.getElementsByTagName("MetarGroup");
	if (groups.length <= 0)
		return -1;
	
    for (var i = 0; i < groups.length; i++) {
		var obj = new Object();
		
		for (var n = 0; n < 99; n++) {
			var tmpText = getElementTextNS("","name",groups[i],n);
			if (tmpText != "n/a")
				obj.groupName = tmpText;
			else
				break;
		}
		
		
		obj.stationList = new Array();
		var stations = groups[i].getElementsByTagName("MetarWrapper");
		for (var j = 0; j < stations.length; j++) {
			var stationObj = new Object();
			stationObj.icao = getElementTextNS("","code",stations[j],0);
			
			var upperIcao = stationObj.icao.toUpperCase();
			var nameFound;
			for (var k=0;k<stationlist.length;k++) {
				nameFound = stationlist[k].n.indexOf(upperIcao,0);
				if (nameFound >= 0) {
					var tmpposC = stationlist[k].n.indexOf("\t",nameFound);			// get airport name
					var tmpposD = stationlist[k].n.indexOf("\t",tmpposC+1);
					var name = stationlist[k].n.substring(tmpposC+1,tmpposD);	
					
					var tmpposC = stationlist[k].n.indexOf("\t",tmpposD);			// get state, if any
					tmpposD = stationlist[k].n.indexOf("\t",tmpposC+1);
					var state = stationlist[k].n.substring(tmpposC+1,tmpposD);
					if (state.length > 1)
						stationObj.name = name + "; " + state;
					else
						stationObj.name = name;
					break;
				}
			}
			
			var tmpText = getElementTextNS("","rule",stations[j],0);
			stationObj.flightRules = tmpText;			

			var tmpText = getElementTextNS("","metarText",stations[j],0);
			stationObj.mTextRaw = tmpText.substring(tmpText.indexOf(stationObj.icao),tmpText.length);
			
			var tmpText = getElementTextNS("","tafText",stations[j],0);
			stationObj.tTextRaw = formatRawData(tmpText.substring(tmpText.indexOf(stationObj.icao),tmpText.length),true);
			obj.stationList.push(stationObj);
		}
		actGroupData.push(obj);
		obj.pageName = getElementTextNS("","title",resXML,0);
    }

	if (obj) {
		populateMyMetarGroupMenu(actGroupData);
		return 0;
	}
	
	return -1;
}



// -----------------------------------------------------------
// CONNECTION HANDLING
// -----------------------------------------------------------

function processNWSReq() 
{
	var err = 0;
	document.getElementById('frontMsg').innerText = "";

    // only if req shows "loaded"
    if (xml_request.readyState == 4) {
        // only if "OK"
        if (xml_request.status == 200) {
			loadNWSData(xml_request.responseText);			// into global objects array "actData"
			err = parseNWSData(0);
						
			lastData = new Array();
			lastData = actData;								// save data in case we lose the connection
			stopProgress();
			
			displayData();
			displayStatusLine("NWS",0);
			firstConnection = false;						// finally we got some data, which we can use later on
		}
		else {
			if (firstConnection) {
				displayMessage("Failed to retrieve data!",true);	// there's nothing else to show :-(
				displayStatusLine("---",2);
				stopProgress();
			}
			else {
				actData = lastData;
				err = parseNWSData(0);
				stopProgress();
				
				displayData();								// display Old Data
				displayMessage("Data might not be current!",true);
				displayStatusLine("NWS",1);
			}
			alert("Failed to retrieve data (" + xml_request.status + "/" + err + ")");
		}
	}
	else {
//		stopProgress();
//		displayStatusLine("-?-",2);
	}
}


function getDataNWS(station_ids)
{	
	xml_request = new XMLHttpRequest();
	xml_request.onreadystatechange = processNWSReq;
	xml_request.overrideMimeType("text/html");
	
	var url = 'http://www.aviationweather.gov/adds/metars/index.php?';
	xml_request.setRequestHeader("Cache-Control", "no-cache");
	
	if (keepPastData)
		url += "station_ids=" + station_ids + "&chk_metars=on&chk_tafs=on&hoursStr=" + keepPastDataHrs + "&std_trans=standard&submitmet=Submit";
	else
		url += "station_ids=" + station_ids + "&chk_metars=on&chk_tafs=on&hoursStr=0&std_trans=standard&submitmet=Submit";
	xml_request.open("GET",url,true);
	xml_request.send(null);

//	xml_request.setRequestHeader("Content-Type","application/x-www-form-urlencoded");

//	if (keepPastData)
//		xml_request.send("station_ids=" + station_ids + "&chk_metars=on&chk_tafs=on&hoursStr=" + keepPastDataHrs + "&std_trans=standard&submit=1");
//	else
//		xml_request.send("station_ids=" + station_ids + "&chk_metars=on&chk_tafs=on&hoursStr=0&std_trans=standard&submit=1");

}


function processMyMetarReq() 
{
	var err = 0;
	document.getElementById('frontMsg').innerText = "";

    // only if req shows "loaded"
    if (xml_request.readyState == 4) {
        // only if "OK"
        if (xml_request.status == 200) {
			if (loadMyMetarData(xml_request.responseXML) == 0) {			// into global objects array "actData"
				displayData();
				displayStatusLine("MyMetar.com",0);
			}
			else {
			//	displayData();
				displayStatusLine("MyMetar.com",1);
				populateMyMetarGroupMenu(null);			// clean up popup menu
				station1Body.innerText = "";
				gVScrollArea.reveal(document.getElementById('station1Body'));
				gVScrollArea.refresh();
			}
			stopProgress();
			
			firstConnection = false;						// finally we got some data, which we can use later on
		}
		else {
			if (firstConnection) {
				displayMessage("Failed to retrieve data!",true);	// there's nothing else to show :-(
				displayStatusLine("MyMetar.com",2);
				stopProgress();
			}

			alert("Failed to retrieve data (" + xml_request.status + "/" + err + ")");
			populateMyMetarGroupMenu(null);			// clean up popup menu
			resizeWindow(document.getElementById("front"),true,0,false);
			station1Head.innerHTML = "";
			gVScrollArea.reveal(document.getElementById('station1Body'));
			gVScrollArea.refresh();
		}
	}
	else {
//		stopProgress();
//		displayStatusLine("-?-",2);
	}
}


function getDataMyMetar(uname)
{	
	xml_request = new XMLHttpRequest();
	xml_request.onreadystatechange = processMyMetarReq;
	xml_request.overrideMimeType("text/xml");

	var url = 'http://www.mymetar.com/' + uname + '/xml';

	xml_request.open("GET",url,true);
	xml_request.setRequestHeader("Cache-Control", "no-cache");
	xml_request.send(null);
}



function getAllData()
{	
	debug = "";
	
	var stations = "";
	for (var i=0;i<5;i++)										// get all presets first
		if (presets[i].icao.length == 4)
			stations = stations + presets[i].icao + ",";

	if (stations == "" && dataSource == 1) {					// is at least one station defined?
		station1Head.innerHTML = "";
		station1Body.innerText = "";
		document.getElementById('flightRulesImage').className = "";
		clearStationInfo();
		graphicalClear();
		resizeWindow(document.getElementById("front"),true,0,false);
		gVScrollArea.reveal(document.getElementById('station1Body'));
		gVScrollArea.refresh();
		displayMessage("No Station defined!",true);
		return;
	}

	if (username == "" && dataSource == 2) {
		station1Head.innerHTML = "";
		station1Body.innerText = "";
		document.getElementById('flightRulesImage').className = "";
		clearStationInfo();
		graphicalClear();
		resizeWindow(document.getElementById("front"),true,0,false);
		gVScrollArea.reveal(document.getElementById('station1Body'));
		populateMyMetarGroupMenu(null);			// clean up popup menu
		gVScrollArea.refresh();
		displayMessage("No User name defined!",true);
		return;
	}
	

	if (!presetsDirty) {										// update only when stations have changed
		return;
	}
	
	actData = new Array();
	actDataDisplay = new Array();
	actGroupData = new Array();

	startProgress();
	switch (dataSource) {
		case 1:	getDataNWS(stations);							// NWS is not the only data source ...
				break;
		case 2:	getDataMyMetar(username);						// support for myMetar.com ...
				break;
		default:
				displayMessage("Default datasource....",true);
				break;
	}
}



// -----------------------------------------------------------
// DISPLAY HANDLING
// -----------------------------------------------------------

function toggleView(event)
{
	if (fetchInProgress)						// don't toggle during updating
		return;

	if (dataSource == 2)						// don't toggle mymetar.com
		return;


	clearStationInfo();
	stopAllAnimationTimers();
	var front = document.getElementById("front");

	if (displayFormat == 1 && !showAll) {		
		if (event.shiftKey) {					// toggle raw to translated
			if (toggleTaf) {
				translatedShowSingleMetar(currentPreset);
				
				var hh = countTableHeight("plate");
				resizeWindow(front,true,hh,false);

			}
			else {
				station1Body.style.visibility = "hidden";
				translatedShowSingleTaf(currentPreset);
				
				var hh = countTableHeight("plate");
				resizeWindow(front,true,hh,false);
				station1Body.style.visibility = "visible";
			}
			toggleTaf = !toggleTaf;
		}
		else {									// toggle back from Info
			rawShowSingle(currentPreset);
		
			var hh = countTableHeight("plateC");
			resizeWindow(front,true,hh,false);
		}
	}
		
	if (displayFormat == 2) {					// toggle translated view only
		if (event.shiftKey) {
			rawShowSingle(currentPreset);
		
			var hh = countTableHeight("plateC");
			resizeWindow(front,true,hh,false);
		}
		else {
			if (toggleTaf) {
				translatedShowSingleMetar(currentPreset);

				var hh = countTableHeight("plate");
				resizeWindow(front,true,hh,false);
			}
			else {
				station1Body.style.visibility = "hidden";
				translatedShowSingleTaf(currentPreset);
				
			
				var hh = countTableHeight("plate");
				resizeWindow(front,true,hh,true);
				station1Body.style.visibility = "visible";
			}
			toggleTaf = !toggleTaf;
		}
	
		if (keepPastData)
			if (toggleTaf) {						// adjust timePrev/timeNext buttons
				timePrevImg.style.visibility = "hidden";
				timeNextImg.style.visibility = "hidden";
			}
			else {
				adjustTimePrevNextButtons();
			}
	}
	
	
	if (displayFormat == 3) {
		if (toggleTaf) {
			station1Body.innerHTML = "";
			graphicalShowSingle(currentPreset);
		}
		else {
			graphicalClear();
			station1Body.style.visibility = "hidden";
			translatedShowSingleTaf(currentPreset);
			
			var hh = countTableHeight("plate");
			resizeWindow(front,true,hh,true);
			station1Body.style.visibility = "visible";
		}
		toggleTaf = !toggleTaf;
	}

	gVScrollArea.reveal(document.getElementById('station1Body'));
	gVScrollArea.refresh();
}


function countTableHeight(plateName)
{
	var plate = document.getElementById(plateName);
	if (plate) {
		var tmp = plate.clientHeight + 118;
		if (tmp < defaultWinHeight)
			tmp = defaultWinHeight;

		return tmp;
	}
	else
		return 100;
}


function getPressureTrend()
{
	if (!keepPastData)
		return "";

	if (actData[currentPreset].metarPast.length >= 1 && actData[currentPreset].metarPastPos == 0) {
		var sumOfPressure = 0;
		for (i=1; i<actData[currentPreset].metarPast.length; i++) {
			sumOfPressure = sumOfPressure + parsePressureOnly(actData[currentPreset].metarPast[i]);
		}
		var pressureAvg = sumOfPressure / (actData[currentPreset].metarPast.length-1);
		var currentPressure = parsePressureOnly(actData[currentPreset].metar);
		if (pressureAvg == currentPressure)
			return "➙";
		else if (pressureAvg > currentPressure)
			return "➘";
		else if (pressureAvg < currentPressure)
			return "➚";
		else
			return "";
	}
	else
		return "";
}


function clickTimePrev()
{
	if (fetchInProgress)						// don't toggle during updating
		return;

	if (actData[currentPreset].metarPastPos < actData[currentPreset].metarPast.length-1) {
		actData[currentPreset].metarPastPos++;
		actData[currentPreset].metar = actData[currentPreset].metarPast[actData[currentPreset].metarPastPos];
		parseNWSData(currentPreset);
		displayData();
		adjustTimePrevNextButtons();
	}
}


function clickTimeNext()
{
	if (fetchInProgress)						// don't toggle during updating
		return;

	if (actData[currentPreset].metarPastPos > 0) {
		actData[currentPreset].metarPastPos--;
		actData[currentPreset].metar = actData[currentPreset].metarPast[actData[currentPreset].metarPastPos];
		parseNWSData(currentPreset);
		displayData();
		adjustTimePrevNextButtons();
	}
}


function resetTimePrevNext()
{
	if (!actData[currentPreset].metarPast)
		return;
	
	if (actData[currentPreset].metarPast[0].indexOf("NIL") > 0 && actData[currentPreset].metarPast.length > 1) {				// use next METAR if latest is NIL
		if (actData[currentPreset].metarPast[1].indexOf("NIL") > 0 && actData[currentPreset].metarPast.length > 2) {			// or even 2nd last one....
			actData[currentPreset].metarPastPos = 2;
			actData[currentPreset].metar = actData[currentPreset].metarPast[2];
		}
		else {
			actData[currentPreset].metarPastPos = 1;
			actData[currentPreset].metar = actData[currentPreset].metarPast[1];
		}
	}
	else {
		actData[currentPreset].metarPastPos = 0;
		actData[currentPreset].metar = actData[currentPreset].metarPast[0];
	}
	parseNWSData(currentPreset);
	adjustTimePrevNextButtons();
}


function adjustTimePrevNextButtons()
{
	if (!keepPastData || actData[currentPreset].metarPast.length <= 1 || (showAll && displayFormat == 1)) {
		timePrevImg.style.visibility = "hidden";
		timeNextImg.style.visibility = "hidden";
		return;
	}
	
	if (currentPreset >= 1 && currentPreset <= 4) {
		if (actData[currentPreset].metarPastPos >= actData[currentPreset].metarPast.length-1)
			timePrevImg.style.visibility = "hidden";
		else
			timePrevImg.style.visibility = "visible";

		if (actData[currentPreset].metarPastPos <= 0)
			timeNextImg.style.visibility = "hidden";
		else	
			timeNextImg.style.visibility = "visible";
		}
}



function displayPastDataFlag()
{
	if (keepPastData && actData[currentPreset].metarPastPos != 0) {
		//
	}
}




function displayDateLine(dateObj,presetNo,withDate,localTime)
{
	if (dateObj == null)
		return getLocalizedString("Timecode is missing.");

	var UTChours = dateObj.getUTCHours();
	var UTCminutes = dateObj.getUTCMinutes();
	var UTCdate = dateObj.getUTCDate();

	
	var dateLT = convertToLocalTime(dateObj,presetNo);
	var hours = dateLT.getHours();
	var minutes = dateLT.getMinutes();	
	
	if (localTime) {
		UTCdate = dateLT.getDate();
	}
	
	if (withDate)  {
		if (metricFormat >= 3) {
			var mDate = " (" + UTCdate + ".)";
		}
		else {
			var tmpDate = UTCdate;
			if (tmpDate == 1 || tmpDate == 21 || tmpDate == 31)
				var mDate = " (" + UTCdate + "st)";
			else
				if (tmpDate == 2 || tmpDate == 22)
					var mDate = " (" + UTCdate + "nd)";
				else
					if (tmpDate == 3 || tmpDate == 23)
						var mDate = " (" + UTCdate + "rd)";
					else
						var mDate = " (" + UTCdate + "th)";
		}
	}
	else {
		var mDate = "";
	}	

	if (metricFormat >= 3) {
		if (localTime)
			var timeTxt = ((hours < 10) ? "0" + hours : hours) + ":" + ((minutes < 10) ? "0" + minutes : minutes) +
					" " + getLocalizedString("Local Time") + mDate;
		else
			var timeTxt = ((UTChours < 10) ? "0" + UTChours : UTChours) + ":" + ((UTCminutes < 10) ? "0" + UTCminutes : UTCminutes)  +  
					" " + getLocalizedString("UTC") + mDate;
	}
	else {
		if (hours >= 0 && hours <= 11) {
			var ampmText = " AM";
			var usHours = hours;
		}
		else {
			var ampmText = " PM";
			var usHours = (hours == 12) ? 12 : hours - 12;
		}
		if (localTime)
			var timeTxt = ((usHours < 10) ? "0" + usHours : usHours) + ":" + ((minutes < 10) ? "0" + minutes : minutes) + ampmText +
					" " + getLocalizedString("Local Time") + mDate;
		else
			var timeTxt = ((UTChours < 10) ? "0" + UTChours : UTChours) + ":" + ((UTCminutes < 10) ? "0" + UTCminutes : UTCminutes)  +  
					" " + getLocalizedString("UTC") + mDate;
	}

	return timeTxt;
}



function displayMessage(message,error)
{
	if (error) {
		document.getElementById('frontMsg').style.color = "#FF9900";
		document.getElementById('frontMsg').innerText = getLocalizedString(message);
	}
	else {
		document.getElementById('frontMsg').style.color = "#CCC";
		document.getElementById('frontMsg').innerText = getLocalizedString(message);
	}
}



function displayStatusLine(sourceStr,err)
{
	var ampmText = "";

	var lastUpdate = new Date();
	if (metricFormat >= 3) {
		var nowStr = ((lastUpdate.getHours() < 10) ? "0" + lastUpdate.getHours() : lastUpdate.getHours()) + ":"
					+ ((lastUpdate.getMinutes() < 10) ? "0" + lastUpdate.getMinutes() : lastUpdate.getMinutes());
		ampmText = "";
	}
	else {
		if (lastUpdate.getHours() >= 0 && lastUpdate.getHours() <= 11) {
			var nowStr = ((lastUpdate.getHours() < 10) ? "0" + lastUpdate.getHours() : lastUpdate.getHours()) + ":"
						+ ((lastUpdate.getMinutes() < 10) ? "0" + lastUpdate.getMinutes() : lastUpdate.getMinutes());
			ampmText = " AM";
		}
		else {
			var usHours = (lastUpdate.getHours() == 12) ? 12 : lastUpdate.getHours() - 12;
			var nowStr = ((usHours < 10) ? "0" + usHours : usHours) + ":"
						+ ((lastUpdate.getMinutes() < 10) ? "0" + lastUpdate.getMinutes() : lastUpdate.getMinutes());
			ampmText = " PM";
		}
	}
		
	var utcText = ((lastUpdate.getUTCHours() < 10) ? "0" + lastUpdate.getUTCHours() : lastUpdate.getUTCHours()) + ":"
					+ ((lastUpdate.getMinutes() < 10) ? "0" + lastUpdate.getMinutes() : lastUpdate.getMinutes());
	
	var updateText = getLocalizedString("Updated at ");
	document.getElementById('statusText').style.color = "black";
	if (showLocalTime || dataSource == 2)
		statusText.innerText = updateText + nowStr + ampmText + ". " + getLocalizedString("Source: ") + sourceStr + "." + debug;
	else
		statusText.innerText = updateText + nowStr + ampmText + " (" + utcText + " UTC). " + getLocalizedString("Source: ") + sourceStr + "." + debug;

	if (err > 0) {
		var updateText = getLocalizedString("Update failed at ");
		document.getElementById('statusText').style.color = "red";
		statusText.innerText = updateText + nowStr + ampmText + ". " + getLocalizedString("Source: ") + sourceStr + "." + debug;
	}
}


function myMetarShowAll()
{
	document.getElementById("station1Body").style.cursor = "default";
	document.getElementById("station1Head").style.cursor = "default";
	document.getElementById('reportTypeImage').className = "";
	
	var tmpHtml = "<table id='plateB' border='0' width='265' cellpadding='1' cellspacing='0'><tr valign='top'><td>";
	var noOfPresets = 0;
	
	if (actGroupData.length > 0) {
		for (var i=0;i<actGroupData[actGroupDataSelected].stationList.length;i++) {
			var rule = actGroupData[actGroupDataSelected].stationList[i].flightRules;
			if (rule != "" && (rule.toUpperCase() == "VFR" || rule.toUpperCase() == "MVFR" || rule.toUpperCase() == "IFR" || rule.toUpperCase() == "LIFR"))
				var ruleImg = " <img src ='Images/mm_" + rule.toLowerCase()  + ".png'> "
			else
				var ruleImg = "";
		
			if (noOfPresets == 0) {						// exception for first stationname
				tmpHtml = tmpHtml + "<span class='stationHeadText'>" + actGroupData[actGroupDataSelected].stationList[i].name + " (" + actGroupData[actGroupDataSelected].stationList[i].icao + ")" + "</span><br>" 
									+ "<img src ='Images/metar.png'> " +  ruleImg + actGroupData[actGroupDataSelected].stationList[i].mTextRaw + "<br>"
									+ "<img src ='Images/taf.png'> " +  actGroupData[actGroupDataSelected].stationList[i].tTextRaw;
									
			}
			else {
				tmpHtml = tmpHtml + "<br><br><span class='stationHeadText'>" + actGroupData[actGroupDataSelected].stationList[i].name + " (" + actGroupData[actGroupDataSelected].stationList[i].icao + ")" + "</span><br>" 
									+ "<img src ='Images/metar.png'> " + ruleImg + actGroupData[actGroupDataSelected].stationList[i].mTextRaw + "<br>"
									+ "<img src ='Images/taf.png'> " +  actGroupData[actGroupDataSelected].stationList[i].tTextRaw;
			}
			noOfPresets++;
		}
			
		station1Head.innerHTML = actGroupData[actGroupDataSelected].pageName;
		station1Body.innerHTML = tmpHtml;
	}
	else {
		station1Head.innerHTML = "";
		station1Body.innerHTML = "";
	}
	
	tmpHtml = tmpHtml + "</td></tr></table>";
			
	var front = document.getElementById("front");
	var hh = countTableHeight("plateB");
	resizeWindow(front,true,hh,false);
}



function rawShowAll()
{
	document.getElementById("station1Body").style.cursor = "default";
	document.getElementById("station1Head").style.cursor = "default";
	document.getElementById('reportTypeImage').className = "";
	
	var tmpHtml = "<table id='plateB' border='0' width='265' cellpadding='1' cellspacing='0'><tr valign='top'><td>";
	var noOfPresets = 0;
	for (var i=1;i<5;i++) {
		if (presets[i].icao.length == 4) {
			if (noOfPresets == 0) {					// exception for first stationname
				tmpHtml = tmpHtml + "<span class='stationHeadText'>" + presets[i].name + " (" + presets[i].icao + ")" + "</span><br>" 
									+ "<img src ='Images/metar.png'> " +  actDataDisplay[i].mTextRaw + "<br>"
									+ "<img src ='Images/taf.png'> " +  actDataDisplay[i].tTextRaw;
									
			}
			else {
				tmpHtml = tmpHtml + "<br><br><span class='stationHeadText'>" + presets[i].name + " (" + presets[i].icao + ")" + "</span><br>" 
									+ "<img src ='Images/metar.png'> " +  actDataDisplay[i].mTextRaw + "<br>"
									+ "<img src ='Images/taf.png'> " +  actDataDisplay[i].tTextRaw;
			}
			noOfPresets++;
		}
	}
			
	tmpHtml = tmpHtml + "</td></tr></table>";
	station1Head.innerHTML = "";
	station1Body.innerHTML = tmpHtml;
			
	if (noOfPresets > 1) {
		var front = document.getElementById("front");
		var hh = countTableHeight("plateB");
		resizeWindow(front,true,hh,false);
	}
			
	if (noOfPresets == 0 && presets[0].icao.length == 4) {
		station1Head.innerHTML = presets[0].name + " (" + preset[0].icao + ")";
		station1Body.innerHTML = "<img src ='Images/metar.png'> " +  actDataDisplay[0].mTextRaw + "<br>" + "<img src ='Images/taf.png'> " +  actDataDisplay[0].tTextRaw;
	}
}


function rawShowSingle(presetNo)
{
	document.getElementById("station1Body").style.cursor = "pointer";
	document.getElementById("station1Head").style.cursor = "default";

	document.getElementById('reportTypeImage').className = "";
	
	var tmpHtml = "<table id='plateC' border='0' width='265' cellpadding='1' cellspacing='0'><tr valign='top'><td>";
	tmpHtml = tmpHtml + "<img src ='Images/metar.png'> " +  actDataDisplay[presetNo].mTextRaw + "<br><br>" + "<img src ='Images/taf.png'> " +  actDataDisplay[presetNo].tTextRaw;
	tmpHtml = tmpHtml + "</td></tr></table>";

	if (presets[presetNo].icao.length == 4) {
		station1Head.innerHTML = presets[presetNo].name + " (" + presets[presetNo].icao + ")";
		station1Body.innerHTML = tmpHtml;
	}
	document.getElementById('flightRulesImage').className = actDataDisplay[presetNo].flightRules;
	
	var front = document.getElementById("front");
	var hh = countTableHeight("plateC");
	resizeWindow(front,true,hh,false);
}


function translatedShowSingleMetar(presetNo)
{
	if (presets[presetNo].icao.length == 4) {
		document.getElementById('reportTypeImage').className = "METAR";
	
		station1Head.innerHTML = presets[presetNo].name + " (" + presets[presetNo].icao + ")";
		if (actDataDisplay[presetNo].mTextTrans == "") {
			station1Body.innerHTML = "<span class='topLeftSpacer'></span> <br>" + getLocalizedString("METAR not available.") + "<br>";
			return false;
		}
				
		if (keepPastData && actData[currentPreset].metarPastPos != 0)
			station1Body.innerHTML = "<span class='topLeftSpacer'></span> " + "<span class='timeHeadPast'>" + getLocalizedString("Observed at: ") + displayDateLine(actDataDisplay[presetNo].mDate,presetNo,true,showLocalTime) + "</span><br>" + actDataDisplay[presetNo].mTextTrans;
		else
			station1Body.innerHTML = "<span class='topLeftSpacer'></span> " + "<span class='timeHead'>" + getLocalizedString("Observed at: ") + displayDateLine(actDataDisplay[presetNo].mDate,presetNo,true,showLocalTime) + "</span><br>" + actDataDisplay[presetNo].mTextTrans;		
		document.getElementById('flightRulesImage').className = actDataDisplay[presetNo].flightRules;
		return true;
	}
	else
		return false;
}


function translatedShowSingleTaf(presetNo)
{
	if (presets[presetNo].icao.length == 4) {
		document.getElementById('reportTypeImage').className = "TAF";
	
		station1Head.innerHTML = presets[presetNo].name + " (" + presets[presetNo].icao + ")";
		if (actDataDisplay[presetNo].tTextTrans == "") {
			station1Body.innerHTML = "<span class='topLeftSpacer'></span> <br>" + getLocalizedString("TAF not available.") + "<br>";
			return false;
		}
	
		station1Body.innerHTML = "<span class='topLeftSpacer'></span> " + "<span class='timeHead'>" + getLocalizedString("Issued at: ") + displayDateLine(actDataDisplay[presetNo].tDate,presetNo,true,showLocalTime) + "</span><br>" + actDataDisplay[presetNo].tTextTrans;
		document.getElementById('flightRulesImage').className = "";		
		return true;
	}
	else
		return false;
}


function translatedShowSingle(presetNo)
{
	document.getElementById("station1Body").style.cursor = "pointer";
	document.getElementById("station1Head").style.cursor = "pointer";
	
	if (!translatedShowSingleMetar(presetNo)) {
		translatedShowSingleTaf(presetNo);
		toggleTaf = true;
	}

	var front = document.getElementById("front");
	var hh = countTableHeight("plate");
	resizeWindow(front,true,hh,false);
}


function graphicalClear()
{
	var canvas = document.getElementById("wind1");
    var context = canvas.getContext("2d");
	context.clearRect(0,0,80,80);

	canvas = document.getElementById("wind1var");
    context = canvas.getContext("2d");
	context.clearRect(0,0,80,80);

	canvas = document.getElementById("weather");
    context = canvas.getContext("2d");
	context.clearRect(0,0,100,20);

	canvas = document.getElementById("clouds");
    context = canvas.getContext("2d");
	context.clearRect(0,0,100,60);

	canvas = document.getElementById("visibility");
    context = canvas.getContext("2d");
	context.clearRect(0,0,120,25);


	graphWind1Img.style.visibility = "hidden";
	graphWind2Img.style.visibility = "hidden";
	graphVisibilityImg.style.visibility = "hidden";
	separatorLeft.style.visibility = "hidden";
	separatorRight.style.visibility = "hidden";

	graphWind1.innerHTML = "";
	graphWind2.innerHTML = "";
	graphWindGusts.innerHTML = "";
	graphTemp.innerHTML = "";
	graphDewpoint.innerHTML = "";
	graphPressure.innerHTML ="";
//	graphDaylight.innerHTML = "";
	graphOberservationTime.innerHTML = "";
	cloudsAlt0.innerHTML = "";
	cloudsAlt1.innerHTML = "";
	cloudsAlt2.innerHTML = "";
	cloudsAlt3.innerHTML = "";
	visibilityText.innerHTML = "";
	weatherText.innerHTML = "";
}


function graphicalShowSingle(presetNo)
{
	document.getElementById("station1Body").style.cursor = "pointer";
	document.getElementById('reportTypeImage').className = "METAR";
	document.getElementById('flightRulesImage').className = actDataDisplay[presetNo].flightRules;

	station1Head.innerHTML = presets[presetNo].name + " (" + presets[presetNo].icao + ")";
//	station1Body.innerText = actDataDisplay[presetNo].gWindDir + "/" + actDataDisplay[presetNo].gWindSpeed;

	if (actDataDisplay[presetNo].mTextTrans == "" || actDataDisplay[presetNo].mTextTrans.indexOf("NIL") > 0) {
	
		// data not available
	
	}
	
	graphWind1Img.style.visibility = "visible";
//	graphWind2Img.style.visibility = "visible";
	graphVisibilityImg.style.visibility = "visible";
	separatorLeft.style.visibility = "visible";
	separatorRight.style.visibility = "visible";

	
	graphDisplayWind(presetNo);
	graphDisplayWeather(presetNo);
	graphDisplayClouds(presetNo);
	graphDisplayVisibility(presetNo);
	
	
	if (actDataDisplay[presetNo].mTextTrans == "" || actDataDisplay[presetNo].mTextTrans.indexOf("NIL") > 0)
		graphTemp.innerText = "--°";
	else
		graphTemp.innerText = actDataDisplay[presetNo].gTemperature + "°";
	
	if (metricFormat == 1)
		graphTemp.innerText = graphTemp.innerText + "F";
	else
		graphTemp.innerText = graphTemp.innerText + "C";
	
	if (actDataDisplay[presetNo].gHumidity == 0)
		graphDewpoint.innerText = "-- %";
	else
		graphDewpoint.innerText = actDataDisplay[presetNo].gHumidity + "%";
	
	if (actDataDisplay[presetNo].gPressure == 0)
		graphPressure.innerHTML = getLocalizedString("Pressure: ") + "<br>" + "---";
	else
		graphPressure.innerHTML = getLocalizedString("Pressure: ") + "<br>" + actDataDisplay[presetNo].gPressure;

	graphOberservationTime.innerHTML = getLocalizedString("Observed at: ") + displayDateLine(actDataDisplay[presetNo].mDate,presetNo,false,showLocalTime);
//	graphDaylight.innerHTML = "<img src='Images/sun.png' width='16' height='16' align='absmiddle' border=0> " + actDataDisplay[presetNo].sunrise +  "&nbsp;&nbsp;<img src='Images/moon.png' width='16' height='16' align='absmiddle' border=0> " + actDataDisplay[presetNo].sunset;

	var front = document.getElementById("front");
	var hh = countTableHeight("plate");
	resizeWindow(front,true,hh,false);
}


function displayData()
{
	station1Head.innerText = "";
	station1Body.innerText = "";
	document.getElementById('flightRulesImage').className = "";
	clearStationInfo();
	toggleTaf = false;
		
	switch (displayFormat) {
		case 1:	graphicalClear();
				if (dataSource == 2)
					myMetarShowAll();
				else
					if (showAll)							// raw
						rawShowAll();
					else
						rawShowSingle(currentPreset);
				break;
		case 2:	graphicalClear();
				translatedShowSingle(currentPreset);		// translated
				break;
		case 3:	graphicalShowSingle(currentPreset);			// graphical
				break;
		default:
				break;
	}
	
	gVScrollArea.reveal(document.getElementById('station1Body'));
	gVScrollArea.refresh();

	switch (dataSource) {									// display post processing
		case 1:	adjustTimePrevNextButtons();
				break;
		case 2:	
				break;
		default:
				break;
	}	
}


// -----------------------------------------------------------
// LOADING  PROGRESS ANIMATION
// -----------------------------------------------------------

var progress = {timer: null, counter:0, up:true, interval:180};

function startProgress()
{
	fetchInProgress = true;

	if (progress.timer != null) {
		clearInterval(progress.timer);
		progress.timer = null;
	}
		
	progress.counter = 0;
	up = true;
	progress.timer = setInterval("playAnimation();",progress.interval);
}


function stopProgress()
{
	if (progress.timer != null) {
		clearInterval(progress.timer);
		progress.timer = null;
	}
		
	document.getElementById('flightRulesImage').className = "";
	fetchInProgress = false;
}


function playAnimation()
{
	if (up)
		progress.counter++;
	else
		progress.counter--;

	switch (progress.counter) {
		case 0:	document.getElementById('flightRulesImage').className = "Ani0";	break;
		case 1:	document.getElementById('flightRulesImage').className = "Ani1";	break;
		case 2:	document.getElementById('flightRulesImage').className = "Ani2";	break;
		case 3:	document.getElementById('flightRulesImage').className = "Ani3";	break;
		case 4:	document.getElementById('flightRulesImage').className = "Ani4";	break;
		case 5:	document.getElementById('flightRulesImage').className = "Ani4";	break;
	}
		
	if (progress.counter >= 5)
		up = false;

	if (progress.counter <= 1)
		up = true;
}



// -----------------------------------------------------------
// PRESS BUTTON ANIMATION
// -----------------------------------------------------------

var gButtonBeingTracked = null;


function mouseDownForButton(inEvent,inThis)
{
	inEvent.target.src = "Images/"+inThis.name+"Pressed.png";
	inEvent.stopPropagation();
	inEvent.preventDefault();
	document.addEventListener("mouseup",mouseUpForButtonsInsideOutside,true);
	gButtonBeingTracked = inThis;
}


function mouseUpForButtonsInsideOutside(inEvent)
{
	if (null != gButtonBeingTracked)
		gButtonBeingTracked.src = "Images/"+gButtonBeingTracked.name+".png";
		
	if (inEvent.target == gButtonBeingTracked) {
		if (inEvent.target.name == "timePrevImg") {
			clickTimePrev();
		}
		else if (inEvent.target.name == "timeNextImg") {
			clickTimeNext();
		}
	}
	
	inEvent.stopPropagation();
	inEvent.preventDefault();
	
	document.removeEventListener("mouseup",mouseUpForButtonsInsideOutside,true);
	gButtonBeingTracked = null;
}



function mouseOutForButton(inEvent,inThis)
{
	inEvent.target.src = "Images/"+inThis.name+".png";
}



function mouseOverForButton(inEvent,inThis)
{
	if (inThis == gButtonBeingTracked)
		inEvent.target.src = "Images/"+inThis.name+"Pressed.png";
}
