/* ------------------------------------------------------------------

File:		AviationWeatherParser.js
Abstract:	METAR/TAF parsing routines
Version:	1.2.11 (02/02/2010)
Author:		Pascal Dreer

------------------------------------------------------------------ */



var extraSM = false;				// used for SM notation, e.g. 1 1/2SM
var extraSMVal = 0;

function roundNumber(num,dig)
{
	var n = Math.pow(10,dig);
	var m = Math.round(num * n) / n;
	return m;
}

function adjustLocalTimeDay(aDay,aHour,obj)		// adjust day by -1 or +1
{
	var hrs = aHour;
	var day = aDay;
	
	var ltOffset = (((parseFloat(obj.timezone) - parseInt(obj.timezone,10)) / 6 * 10) / 60 ) + parseInt(obj.timezone,10);
	var dateLT = new Date();
	
	if (adjustSummertime(dateLT,currentPreset,false))
		hrs++;
	if (hrs + ltOffset >= 24)
		day++;
	else
		if (hrs + ltOffset < 0)
			day--;

	if (day >= 32)
		day = day - 31;
	return day;
}


function parseWind(elemStr,obj)
{
	if (elemStr.substr(0,5) == "00000")
		return  "<tr valign='top'><td>" + getLocalizedString("Wind: ") + "</td><td>" + getLocalizedString("calm") + "</td></tr>"


	var tmpStr1 = elemStr.substr(0,3);
	
	if (isNaN(parseInt(elemStr.substr(3,2),10)))
		var tmpVal2 = parseInt(elemStr.substr(4,1),10);
	else
		var tmpVal2 = parseInt(elemStr.substr(3,2),10);


	var addGusts = "";
	var gusts = 0;

	if (elemStr.indexOf("KT") > 0) {								// wind speed
		var tmpStr3 = getLocalizedString("knots");
		if (metricFormat <= 2) {
			var tmpStr2 = String(tmpVal2 * 1.1508122);
			var n = Math.pow(10,0);
			var m = Number(tmpStr2.substr(0,4));
			tmpStr3 = tmpStr3 + " (~" + String(Math.round(m * n) / n) + " MPH)";
			if (elemStr.indexOf("G") > 0) {					// gusts
				var tmpStr2 = String(parseInt(elemStr.substr(6,2),10) * 1.1508122);
				var n = Math.pow(10,0);
				var m = Number(tmpStr2.substr(0,4));
				tmpStr2 = " (~" + String(Math.round(m * n) / n) + " MPH)";
				addGusts = " " + getLocalizedString("gusting") + " " + getLocalizedString("to") + " " + parseInt(elemStr.substr(6,2),10) + " " + getLocalizedString("knots") + tmpStr2;
				var gusts = parseInt(elemStr.substr(6,2),10);
			}
		}
		if (metricFormat >= 3) {
			var tmpStr2 = String(tmpVal2 * 1.852);
			var n = Number(tmpStr2.substr(0,4));
			tmpStr3 = tmpStr3 + " (~" + Math.round(n) + " km/h)";
			if (elemStr.indexOf("G") > 0) {					// gusts
				var tmpStr2 = String(parseInt(elemStr.substr(6,2),10) * 1.852);
				var n = Number(tmpStr2.substr(0,4));
				tmpStr2 = " (~" + Math.round(n) + " km/h)";
				addGusts = " " + getLocalizedString("gusting") + " " + getLocalizedString("to") + " " + parseInt(elemStr.substr(6,2),10) + " " + getLocalizedString("knots") + tmpStr2;
				var gusts = parseInt(elemStr.substr(6,2),10);
			}
		}
	}

	
	if (elemStr.indexOf("MPS") > 0) {
		var tmpStr3 = "MPS";
		if (metricFormat <= 2) {
			var tmpStr2 = String(tmpVal2 * 2.237);
			var n = Math.pow(10,0);
			var m = Number(tmpStr2.substr(0,4));
			tmpStr3 = tmpStr3 + " (~" + String(Math.round(m * n) / n) + " MPH)";
			if (elemStr.indexOf("G") > 0) {					// gusts
				var tmpStr2 = String(parseInt(elemStr.substr(6,2),10) * 2.237);
				var n = Math.pow(10,0);
				var m = Number(tmpStr2.substr(0,4));
				tmpStr2 = " (~" + String(Math.round(m * n) / n) + " MPH)";
				addGusts = " " + getLocalizedString("gusting") + " " + getLocalizedString("to") + " " + parseInt(elemStr.substr(6,2),10) + " " + "MPS" + tmpStr2;
				var gusts = parseInt(elemStr.substr(6,2),10);
			}
		}
		if (metricFormat >= 3) {
			var tmpStr2 = String(tmpVal2 * 3.6);
			var n = Number(tmpStr2.substr(0,4));
			tmpStr3 = tmpStr3 + " (~" + Math.round(n) + " km/h)";
			if (elemStr.indexOf("G") > 0) {					// gusts
				var tmpStr2 = String(parseInt(elemStr.substr(6,2),10) * 3.6);
				var n = Number(tmpStr2.substr(0,4));
				tmpStr2 = " (~" + Math.round(n) + " km/h)";
				addGusts = " " + getLocalizedString("gusting") + " " + getLocalizedString("to") + " " + parseInt(elemStr.substr(6,2),10) + " " + "MPS" + tmpStr2;
				var gusts = parseInt(elemStr.substr(6,2),10);
			}
		}	
	}
		
	
	if (tmpStr1 == "VRB") {									// wind direction
		var windStr = getLocalizedString("variable") + " ";
		var deg = -1;
	}
	else {
		var deg = parseInt(tmpStr1,10);
		var degStr = "";

		if (deg >= 0 && deg <= 11)
			degStr = "N";
		if (deg > 11 && deg <= 33)
			degStr = "NNE";
		if (deg > 33 && deg <= 56)
			degStr = "NE";
		if (deg > 56 && deg <= 78)
			degStr = "ENE";
		if (deg > 78 && deg <= 101)
			degStr = "E";
		
		if (deg > 101 && deg <= 123)
			degStr = "ESE";
		if (deg > 123 && deg <= 146)
			degStr = "SE";
		if (deg > 146 && deg <= 168)
			degStr = "SSE";
		if (deg > 168 && deg <= 191)
			degStr = "S";


		if (deg > 191 && deg <= 213)
			degStr = "SSW";
		if (deg > 213 && deg <= 236)
			degStr = "SW";
		if (deg > 236 && deg <= 258)
			degStr = "WSW";
		if (deg > 258 && deg <= 281)
			degStr = "W";
			
		if (deg > 281 && deg <= 303)
			degStr = "WNW";
		if (deg > 303 && deg <= 326)
			degStr = "NW";
		if (deg > 326 && deg <= 348)
			degStr = "NNW";
		if (deg > 348 && deg <= 360)
			degStr = "N";
			
		var windStr = tmpStr1 + " " + getLocalizedString("degrees") + " (" + degStr + ") ";
	}
	
	
	if (obj != null) {
		obj.gWindDir = deg;
		obj.gWindSpeed = tmpVal2;
		obj.gWindGusts = gusts;
	}
	
	var returnStr = "<tr valign='top'><td>" + getLocalizedString("Wind: ") + "</td><td>" +  windStr + tmpVal2 + " " + tmpStr3 + addGusts + "</td></tr>";
	return returnStr;
}


function parseVariableWind(elemStr,obj)
{
	var tmpStr1 = elemStr.substr(0,3);
	var tmpStr2 = elemStr.substr(4,3);
	var returnStr = "<tr valign='top'><td></td><td>" + getLocalizedString("variable between") + " " + tmpStr1 + " " + getLocalizedString("and") + " " + tmpStr2 + " " + getLocalizedString("degrees") + "</td></tr>";

	if (obj != null) {
		obj.gWindVar1 = Number(tmpStr1);
		obj.gWindVar2 = Number(tmpStr2);
	}

	return returnStr;
}


function parseVisibilty(elemStr,obj)
{
	if (elemStr.indexOf("9999") >= 0) {
		if (metricFormat <= 2)
			var returnStr = "<tr valign='top'><td>" + getLocalizedString("Visibility: ") + "</td><td>" + getLocalizedString("6 or more miles") + "</td></tr>";
		else
			var returnStr = "<tr valign='top'><td>" + getLocalizedString("Visibility: ") + "</td><td>" + getLocalizedString("10 km or more") + "</td></tr>";

		if (obj != null) 
			obj.gVisibility = 10000;
	}
	else {
		if (metricFormat <= 2) {
			var tmpStr = String(parseInt(elemStr,10) / 1000 * 0.62137119);
			var tmpVal = tmpStr.substr(0,tmpStr.indexOf(".")+2);
			if (parseInt(tmpVal,10) == 1)
				var returnStr = "<tr valign='top'><td>" + getLocalizedString("Visibility: ") + "</td><td>" + tmpVal + " " + getLocalizedString("mile") + "</td></tr>";
			else
				var returnStr = "<tr valign='top'><td>" + getLocalizedString("Visibility: ") + "</td><td>" + tmpVal + " " + getLocalizedString("miles") + "</td></tr>";

			if (obj != null) 
				obj.gVisibility = tmpVal;
		}
		else {
			var returnStr = "<tr valign='top'><td>" + getLocalizedString("Visibility: ") + "</td><td>" + parseInt(elemStr,10) + " " + getLocalizedString("meter") + "</td></tr>";
			if (obj != null) 
				obj.gVisibility = parseInt(elemStr,10);
		}
	}
	
	return returnStr;
}


function parseVisibilty2(elemStr,obj)
{
	returnStr = "";

	if (elemStr.indexOf("CAVOK") >= 0)
		var returnStr = "<tr valign='top'><td>" + getLocalizedString("Visibility: ") + "</td><td>" + getLocalizedString("Ceiling and Visibility OK") + "</td></tr>";
	
	if (elemStr.indexOf("KM") >= 0) {
		var tmpVal = elemStr.substring(0,elemStr.indexOf("KM"));
		
		var kmstr = elemStr.substring(elemStr.indexOf("KM"),elemStr.length);
		if (kmstr.length == 3)
			var visiDir = ", " + getLocalizedString("direction") + " " + kmstr.charAt(2);
		else
			if (kmstr.length == 4)
				var visiDir = ", " + getLocalizedString("direction") + " " + kmstr.substr(2,2);
			else
				if (kmstr.indexOf("NDV",3) >= 0)
					var visiDir = ", " + getLocalizedString("no directional variation");
				else
					var visiDir = "";		
		
		if (metricFormat <= 2) {
			var tmpStr = String(parseInt(tmpVal,10) * 0.62137119);
			var tmpVal = tmpStr.substr(0,tmpStr.indexOf(".")+2);
			if (parseInt(tmpVal,10) == 1)
				var returnStr = "<tr valign='top'><td>" + getLocalizedString("Visibility: ") + "</td><td>" + tmpVal + " " + getLocalizedString("mile") + visiDir + "</td></tr>";
			else
				var returnStr = "<tr valign='top'><td>" + getLocalizedString("Visibility: ") + "</td><td>" + tmpVal + " " + getLocalizedString("miles") + visiDir + "</td></tr>";
		}
		else
			var returnStr = "<tr valign='top'><td>" + getLocalizedString("Visibility: ") + "</td><td>" + tmpVal + " km" + visiDir + "</td></tr>";

		if (obj != null) 
			obj.gVisibility = tmpVal * 1000;
	}
	

	
	if (elemStr.indexOf("SM") >= 0) {
		if (elemStr.charAt(0) == "P") {
			var tmpVal = elemStr.substr(1,1);
		}
		else {
			var tmp3 = elemStr.indexOf("/");
			if (tmp3 > 0) {
				var tmpVal = parseInt(elemStr.substr(tmp3-1,1),10) / parseInt(elemStr.substr(tmp3+1,1),10);
			}
			else {
				var tmpVal = parseInt(elemStr.substring(0,elemStr.indexOf("SM")),10);
			}
			if (extraSM) {
				tmpVal = tmpVal + parseInt(extraSMVal,10);
			}
		}
	
		if (metricFormat >= 3) {
			var tmpStr = String(tmpVal * 1.609344);
			var tmpVal = tmpStr.substr(0,tmpStr.indexOf(".")+2);
			if (tmpVal.length >= 4)										// no decimals when value greather than 10km
				var tmpVal = tmpStr.substr(0,tmpStr.indexOf("."));
			var returnStr = "<tr valign='top'><td>" + getLocalizedString("Visibility: ") + "</td><td>" + tmpVal + " km" + "</td></tr>";
		}
		else
			if (parseInt(tmpVal,10) == 1)
				var returnStr = "<tr valign='top'><td>" + getLocalizedString("Visibility: ") + "</td><td>" + tmpVal + " " + getLocalizedString("mile") + "</td></tr>";
			else
				var returnStr = "<tr valign='top'><td>" + getLocalizedString("Visibility: ") + "</td><td>" + tmpVal + " " + getLocalizedString("miles") + "</td></tr>";
	
		if (obj != null) 
			obj.gVisibility = tmpVal * 1000;
	}

	return returnStr;
}


function parseVisibilty3(elemStr)
{	
	if (elemStr.length == 5)
		var visiDir = getLocalizedString("direction") + " " + elemStr.charAt(4);
	else
		if (elemStr.length == 6)
			var visiDir = getLocalizedString("direction") + " " + elemStr.substr(4,2);
		else
			if (elemStr.indexOf("NDV",3) >= 0)
				var visiDir = getLocalizedString("no directional variation");
			else
				var visiDir = "";
	
	
	if (elemStr.indexOf("9999") >= 0) {
		if (metricFormat <= 2)
			var returnStr = "<tr valign='top'><td>" + getLocalizedString("Visibility: ") + "</td><td>" + getLocalizedString("6 or more miles") + ", " + visiDir + "</td></tr>";
		else
			var returnStr = "<tr valign='top'><td>" + getLocalizedString("Visibility: ") + "</td><td>" + getLocalizedString("10 km or more") + ", " + visiDir + "</td></tr>";
	}
	else {
		if (metricFormat <= 2) {
			var tmpStr = String(parseInt(elemStr,10) / 1000 * 0.62137119);
			var tmpVal = tmpStr.substr(0,tmpStr.indexOf(".")+2);
			var returnStr = "<tr valign='top'><td>" + getLocalizedString("Visibility: ") + "</td><td>" + tmpVal + " " + getLocalizedString("miles") + ", " + visiDir + "</td></tr>";
		}
		else {
			var returnStr = "<tr valign='top'><td>" + getLocalizedString("Visibility: ") + "</td><td>" + parseInt(elemStr,10) + " " + getLocalizedString("meter") + ", " + visiDir + "</td></tr>";
		}
	}
	
	return returnStr;
}




function parseClouds(elemStr)
{
	var addClouds = "";

	var tmpStr = elemStr.substr(0,3);
	if (elemStr.charAt(3) == "C" && elemStr.charAt(4) == "B") {
		var tmpVal = parseInt(elemStr.substr(5,3),10) * 100;
		addClouds = " ("+ getLocalizedString("cumulonimbus") + ")";
	}
	else
		var tmpVal = parseInt(elemStr.substr(3,3),10) * 100;

	if (elemStr.length == 8) {
		if (elemStr.charAt(6) == "C" && elemStr.charAt(7) == "U")
			addClouds = " ("+ getLocalizedString("cumulus") + ")";

		if (elemStr.charAt(6) == "C" && elemStr.charAt(7) == "B")
			addClouds = " ("+ getLocalizedString("cumulonimbus") + ")";
	}
	
	if (elemStr.length == 9)
		if (elemStr.charAt(6) == "T" && elemStr.charAt(7) == "C")
			addClouds = " ("+ getLocalizedString("towering cumulus") + ")";
	
	
	if (tmpStr == "FEW") 
		var cloudType = getLocalizedString("few clouds");
	if (tmpStr == "SCT") 
		var cloudType = getLocalizedString("scattered clouds");
	if (tmpStr == "BKN") 
		var cloudType = getLocalizedString("broken clouds");
	if (tmpStr == "OVC") 
		var cloudType = getLocalizedString("overcast clouds");


	if (metricFormat <= 3) {
		if (isNaN(tmpVal))
			var returnStr = cloudType + addClouds;
		else
			var returnStr = cloudType + " " + getLocalizedString("at") + " " +  tmpVal + " " + getLocalizedString("feet") + addClouds;
	}
	else {
		if (isNaN(tmpVal)) 
			var returnStr = cloudType + addClouds;
		else {
			tmpVal = Math.round(tmpVal * 0.3048 / 10) * 10;
			var returnStr = cloudType + " " + getLocalizedString("at") + " " +  tmpVal + " " + getLocalizedString("meter") + addClouds;
		}
	}
	return returnStr;
}


function parseClouds2(elemStr)
{
	if (elemStr == "CLR")
		if (metricFormat <= 3)
			return getLocalizedString("clear below 12,000 feet");
		else
			return getLocalizedString("clear below 3600 meter");
	
		
	if (elemStr == "SKC")
		return getLocalizedString("sky clear");	
	
	if (elemStr.indexOf("VV///") >= 0)
		return getLocalizedString("Vertical visibility") + " " + getLocalizedString("height not available");
	
	if (elemStr.indexOf("VV") >= 0) {
		if (metricFormat <= 2) {
			tmpStr =  parseInt(elemStr.substr(2,3),10) * 100;
			return getLocalizedString("Vertical visibility") + " " + tmpStr + " " + getLocalizedString("feet");
		}
		else {
			tmpStr =  Math.round((parseInt(elemStr.substr(2,3),10) * 100) * 0.3048 / 10) * 10;
			return getLocalizedString("Vertical visibility") + " " + tmpStr + " " + getLocalizedString("meter");
		}
		
	}
	return "";
}


function parseWeatherDescriptor(descStr)
{
	var desc2 = "";

	switch (descStr) {
		case "MI": desc2 = getLocalizedString("shallow");
			break;
		case "BC": desc2 = getLocalizedString("patches");
			break;
		case "PR": desc2 = getLocalizedString("partial");
			break;
		case "DR": desc2 = getLocalizedString("low drifting");
			break;
		case "BL": desc2 = getLocalizedString("blowing");
			break;
		case "SH": desc2 = getLocalizedString("showers");
			break;
		case "TS": desc2 = getLocalizedString("thunderstorm");
			break;
		case "FZ": desc2 = getLocalizedString("freezing");
			break;
		case "DZ": desc2 = getLocalizedString("drizzle");
			break;
		case "RA": desc2 = getLocalizedString("rain");
			break;
		case "SN": desc2 = getLocalizedString("snow");
			break;
		case "SG": desc2 = getLocalizedString("snow grains");
			break;
		case "IC": desc2 = getLocalizedString("ice crystals");
			break;
		case "PL": desc2 = getLocalizedString("ice pellets");
			break;
		case "GR": desc2 = getLocalizedString("hail");
			break;
		case "GS": desc2 = getLocalizedString("small hail or snow pellets");
			break;
		case "FG": desc2 = getLocalizedString("fog");
			break;
		case "BR": desc2 = getLocalizedString("mist");
			break;
		case "FU": desc2 = getLocalizedString("smoke");
			break;
		case "VA": desc2 = getLocalizedString("volcanic ash");
			break;
		case "DU": desc2 = getLocalizedString("widespread dust");
			break;
		case "SA": desc2 = getLocalizedString("sand");
			break;
		case "HZ": desc2 = getLocalizedString("haze");
			break;
		case "PO": desc2 = getLocalizedString("dust/sand whirls");
			break;
		case "SQ": desc2 = getLocalizedString("squalls");
			break;
		case "FC": desc2 = getLocalizedString("funnel clouds");
			break;
		case "SS": desc2 = getLocalizedString("sandstorm");
			break;
		case "DS": desc2 = getLocalizedString("duststorm");
			break;
		case "CB": desc2 = getLocalizedString("cumulonimbus");
			break;
	}
		
	return desc2;
}


function parseWeather(elemStr,obj)
{
	var desc1 = "";
	var nextPos = 0;
	
	if (elemStr.charAt(0) == "-") {
		desc1 = getLocalizedString("light");
		nextPos = 1;
		if (obj != null)
			obj.gWeather0 = "-";
	}
	if (elemStr.charAt(0) == "+") {
		desc1 = getLocalizedString("heavy");
		nextPos = 1;
		if (obj != null)
			obj.gWeather0 = "+";
	}
	if (elemStr.charAt(0) == "V" && elemStr.charAt(1) == "C") {
		desc1 = getLocalizedString("in the vicinity");
		nextPos = 2;
	}
	
	var desc2 = "";
	var descStr = elemStr.substr(nextPos,2);
	var desc2 = parseWeatherDescriptor(descStr);
	nextPos = nextPos + 2;
	
	if (obj != null)
		obj.gWeather1 = descStr;

	
	var desc3 = "";
	if (elemStr.length >= 3) {
		var descStr = elemStr.substr(nextPos,2);
		var desc3 = parseWeatherDescriptor(descStr);
		nextPos = nextPos + 2;
		if (obj != null)
			obj.gWeather2 = descStr;
	}
	
	var desc4 = "";
	if (elemStr.length >= 5) {
		var descStr = elemStr.substr(nextPos,2);
		var desc4 = parseWeatherDescriptor(descStr);
		nextPos = nextPos + 2;
	}

	if (desc1.length != 0 || desc2.length != 0 || desc3.length != 0 || desc4.length != 0)
		var returnStr = desc1 + " " + desc2 + " " + desc3 + " " + desc4;
	else
		var returnStr = "";
		

	return returnStr;
}


function parseRecent(elemStr)
{
	var descStr = elemStr.substr(2,2);
	var desc = parseWeatherDescriptor(descStr);

	var returnStr = "<tr valign='top'><td>" + getLocalizedString("Info: ") + "</td><td>" + getLocalizedString("recent") + " " + desc + "</td></tr>";
	return returnStr;
}


function parseWindshearRwy(elemStr)
{
	var rwy = "";
	if (elemStr.indexOf("ALL") >= 0)
		rwy = getLocalizedString("all runways");
	else {
		if (elemStr.indexOf("TKOF") >= 0)
			rwy = getLocalizedString("takeoff") + " ";
		else
			if (elemStr.indexOf("LDG") >= 0)
				rwy = getLocalizedString("landing") + " ";
		
		if (elemStr.indexOf("RWY") >= 0) {
			var rwyNo = elemStr.substr(3,2);
			rwy = rwy + getLocalizedString("runway") + " " + rwyNo;
		}
		else 
			if (elemStr.indexOf("R") >= 0) {
			var rwyNo = elemStr.substr(1,2);
			rwy = rwy + getLocalizedString("runway") + " " + rwyNo;
		}
	}

	var returnStr = "<tr valign='top'><td>" + getLocalizedString("Windshear:") + "</td><td>" + rwy + "</td></tr>";
	return returnStr;
}



function parseWindshear(elemStr)
{
	var tmp = elemStr.indexOf("/");
	if (tmp > 0) {
		var windStr = elemStr.substr(tmp + 1,3) + " " + getLocalizedString("degrees") + " ";

		if (elemStr.charAt(11) == "K")
			var tmpStr3 = getLocalizedString("knots");
		else
			var tmpStr3 = "MPS";

		var tmpVal2 = parseInt(elemStr.substr(tmp + 4,2),10);

		if (metricFormat <= 2 && elemStr.charAt(11) == "K") {
			var tmpStr2 = String(tmpVal2 * 1.1508122);
			var n = Math.pow(10,0);
			var m = Number(tmpStr2.substr(0,4));
			tmpStr = tmpStr3 + " (~" + String(Math.round(m * n) / n) + " MPH)";
		}
	
		if (metricFormat >= 3 && elemStr.charAt(11) == "K") {
			var tmpStr2 = String(tmpVal2 * 1.852);
			var n = Number(tmpStr2.substr(0,4));
			tmpStr = tmpStr3 + " (~" + Math.round(n) + " km/h)";
		}
		
		windStr = windStr + getLocalizedString("at") + " " +tmpVal2 + " " + tmpStr;
		var addWind = ", " + windStr;
	}
	else
		var addWind = "";
		

	var tmpVal = parseInt(elemStr.substr(2,3),10) * 100;
	if (metricFormat <= 3)
		var windshearStr = getLocalizedString("at") + " " +  tmpVal + " " + getLocalizedString("feet") +  addWind;
	else {
		tmpVal = Math.round(tmpVal * 0.3048 / 10) * 10;
		var windshearStr = getLocalizedString("at") + " " +  tmpVal + " " + getLocalizedString("meter") + addWind;
	}

	var returnStr = "<tr valign='top'><td>" + getLocalizedString("Windshear:") + "</td><td>" + windshearStr + "</td></tr>";
	return returnStr;
}



function parseTrendRVR(elemStr)			// exapmle: LSZH R14/P1500N R16/1000VP1500D R28/P1500N R34/P1500N R31//////N 
{
	var tmpStr = "";
	var tmp = elemStr.indexOf("/");
	var rwy = elemStr.substring(1,tmp);
	
	if (elemStr.indexOf("/////",tmp) >= 0) {
		tmp = tmp + 6;
	}
	else {
	
	if (elemStr.charAt(tmp+1) == "M") {
		var tmpStr = getLocalizedString("minus") + " ";
		tmp = tmp + 2;
	}
	else		
		if (elemStr.charAt(tmp+1) == "P") {
			var tmpStr = getLocalizedString("plus") + " ";
			tmp = tmp + 2;
		}
		else
			tmp++;
	
	var tmpFt = elemStr.indexOf("FT");
	if (tmpFt <= 0) {							// range in meters
		if (metricFormat >= 3)
			tmpStr = tmpStr + parseInt(elemStr.substr(tmp,4),10);
		else {
			var tmpVal = parseInt(elemStr.substr(tmp,4),10);
			tmpStr = tmpStr + Math.round(tmpVal * 3.2808399 / 10) * 10;
		}
	}
	else {										// range in feet
		if (metricFormat >= 3) {
			var tmpVal = parseInt(elemStr.substr(tmp,4),10);
			tmpStr = tmpStr + Math.round(tmpVal * 0.3048 / 10) * 10;
		}
		else {
			tmpStr = tmpStr + parseInt(elemStr.substr(tmp,4),10);
		}
	}
	
	tmp = tmp + 4;
	
	if (elemStr.charAt(tmp) == "V") {
		tmpStr = tmpStr + " " + getLocalizedString("to") + " ";

		if (elemStr.charAt(tmp+1) == "M") {
			tmpStr = tmpStr + getLocalizedString("minus") + " ";
			tmp = tmp + 2;
		}
		else
			if (elemStr.charAt(tmp+1) == "P") {
				tmpStr = tmpStr + getLocalizedString("plus") + " ";
				tmp = tmp + 2;
			}
			else
				tmp = tmp + 1;

		if (tmpFt <= 0) {							// range in meters
			if (metricFormat >= 3)
				tmpStr = tmpStr + parseInt(elemStr.substr(tmp,4),10);
			else {
				var tmpVal = parseInt(elemStr.substr(tmp,4),10);
				tmpStr = tmpStr + Math.round(tmpVal * 3.2808399 / 10) * 10;
			}
		}
		else {										// range in feet
			if (metricFormat >= 3) {
				var tmpVal = parseInt(elemStr.substr(tmp,4),10);
				tmpStr = tmpStr + Math.round(tmpVal * 0.3048 / 10) * 10;
			}
			else
				tmpStr = tmpStr + parseInt(elemStr.substr(tmp,4),10);
		}
		tmp = tmp + 4;
	}
	
	if (metricFormat >= 3)
		tmpStr = tmpStr + " " + getLocalizedString("meter");
	else
		tmpStr = tmpStr + " " + getLocalizedString("feet");
		
	}
	
	if (elemStr.charAt(tmp) == "N") {
		var tmpStr = tmpStr + " " + getLocalizedString("no change");
	}
	if (elemStr.charAt(tmp) == "U") {
		var tmpStr = tmpStr + " " + getLocalizedString("up");
	}
	if (elemStr.charAt(tmp) == "D") {
		var tmpStr = tmpStr + " " + getLocalizedString("down");
	}
	
	var returnStr = "<tr valign='top'><td width='75'>" + getLocalizedString("Visual Range:") + "</td><td>" +  getLocalizedString("runway") + " " + rwy + ": " + tmpStr + "</td></tr>";
	return returnStr;
}


function parseTrendRVRXXXXX(elemStr)
{
	if (elemStr.charAt(0) == "M")
		var tmpStr = getLocalizedString("deterioration");
	else
		if (elemStr.charAt(0) == "B")
			var tmpStr = getLocalizedString("improvement");
		else
			return "";

	var descStr = "";
	switch (elemStr.charAt(1)) {
		case "0": descStr = getLocalizedString("max wind speed");
			break;
		case "1": descStr = getLocalizedString("average wind speed and direction");
			break;
		case "2": descStr = getLocalizedString("runway visual range");
			break;
		case "3": descStr = getLocalizedString("clouds");
			break;
		case "4": descStr = getLocalizedString("precipitations");
			break;
		case "7": descStr = getLocalizedString("dust storm, sand storm or snow storm");
			break;
		case "8": descStr = getLocalizedString("storm with or without precipitations");
			break;
		case "9": descStr = getLocalizedString("squalls");
			break;
	}

	var returnStr = "<tr valign='top'><td>" + getLocalizedString("RVR trend: ") + "</td><td>" + tmpStr + ": " + descStr + "</td></tr>";
	return returnStr;
}


function parseRunwayReport(elemStr)
{
	var tmpStr = "";

	var rwyId = elemStr.substr(0,2);
	if (rwyId == "88")
		tmpStr = getLocalizedString("all runways");
	else
		if (rwyId == "99")
			tmpStr = getLocalizedString("report repetition");
		else
			tmpStr = getLocalizedString("runway") + " " + rwyId;
	
	var tmppos = elemStr.indexOf("CLRD");
	if (tmppos >= 0) {
		tmpStr = tmpStr + " " + getLocalizedString("cleared");
	}
	else {
		var rwyDeposit = elemStr.substr(2,1);
		tmpStr = tmpStr + " ";
		switch (rwyDeposit) {
			case "0": tmpStr = tmpStr + getLocalizedString("clear and dry");
				break;
			case "1": tmpStr = tmpStr + getLocalizedString("damp");
				break;
			case "2": tmpStr = tmpStr + getLocalizedString("wet or puddles");
				break;
			case "3": tmpStr = tmpStr + getLocalizedString("frost");
				break;
			case "4": tmpStr = tmpStr + getLocalizedString("dry snow");
				break;
			case "5": tmpStr = tmpStr + getLocalizedString("wet snow");
				break;
			case "6": tmpStr = tmpStr + getLocalizedString("slush");
				break;
			case "7": tmpStr = tmpStr + getLocalizedString("ice");
				break;
			case "8": tmpStr = tmpStr + getLocalizedString("compacted snow");
				break;
			case "9": tmpStr = tmpStr + getLocalizedString("frozen ridges");
				break;
			case "/": ;
				break;
		}
				
		var rwyDepositExtent = elemStr.substr(3,1);
		switch (rwyDepositExtent) {
			case "1": tmpStr = tmpStr + " " + "1-10%";
				break;
			case "2": tmpStr = tmpStr + " " + "11-25%";
				break;
			case "5": tmpStr = tmpStr + " " + "26-50%";
				break;
			case "9": tmpStr = tmpStr + " " + "51-100%";
				break;
			case "/": ;
				break;
		}
		
		var rwyDepositDepth = elemStr.substr(4,2);
		if (rwyDepositDepth == "//") {
		}
		else {
			var rwyDepositDepthNum = parseInt(rwyDepositDepth,10);
			if (rwyDepositDepthNum == 0) {
				tmpStr = tmpStr + " " + getLocalizedString("less than 1mm");
			}
			else {
				if (rwyDepositDepthNum >= 1 && rwyDepositDepthNum <= 90) {
					tmpStr = tmpStr + " " + rwyDepositDepthNum + "mm";
				}
				else {
					switch (rwyDepositDepth) {
						case "92": tmpStr = tmpStr + " " + "10cm";
							break;
						case "93": tmpStr = tmpStr + " " + "15cm";
							break;
						case "94": tmpStr = tmpStr + " " + "20cm";
							break;
						case "95": tmpStr = tmpStr + " " + "25cm";
							break;
						case "96": tmpStr = tmpStr + " " + "30cm";
							break;
						case "97": tmpStr = tmpStr + " " + "35cm";
							break;
						case "98": tmpStr = tmpStr + " " + "40cm";
							break;
						case "99": tmpStr = tmpStr + " " + getLocalizedString("not in use");
							break;
					}
				}
			}
		}
	}
	
	var rwyBreak = elemStr.substr(6,2);
	if (rwyBreak == "//") {
		
	}
	else {
		tmpStr = tmpStr + ", ";
		var rwyBreakNum = parseInt(rwyBreak,10);
		if (rwyBreakNum >= 1 && rwyBreakNum <= 90) {
 			tmpStr = tmpStr + getLocalizedString("friction coefficient") + " " + (rwyBreakNum / 100);
		}
		else {
			switch (rwyBreak) {
				case "91": tmpStr = tmpStr + getLocalizedString("poor braking action");
					break;
				case "92": tmpStr = tmpStr + getLocalizedString("poor/medium braking action");
					break;
				case "93": tmpStr = tmpStr + getLocalizedString("medium braking action");
					break;
				case "94": tmpStr = tmpStr + getLocalizedString("medium/good braking action");
					break;
				case "95": tmpStr = tmpStr + getLocalizedString("good braking action");
					break;
				case "99": tmpStr = tmpStr + getLocalizedString("unreliable measurement");
					break;
			}
		}
	}
	
	var returnStr = "<tr valign='top'><td>" + getLocalizedString("Rwy report:") + "</td><td>" + tmpStr + "</td></tr>";
	return returnStr;
}



function parseIcingTurbulence(elemStr)
{
	var tmpStr = "";
	if (elemStr.substr(0,1) == "5") {
		var groupStr = getLocalizedString("Turbulence:");
		var typeStr = "";
		var tmpStr = elemStr.substr(1,1);
		switch (tmpStr) {
			case "0": typeStr = getLocalizedString("none");
				break;
			case "1": typeStr = getLocalizedString("light turbulence");
				break;
			case "2": typeStr = getLocalizedString("mod. clear air turbulence (occasional)");
				break;
			case "3": typeStr = getLocalizedString("mod. clear air turbulence (frequent)");
				break;
			case "4": typeStr = getLocalizedString("mod. in cloud turbulence (occasional)");
				break;
			case "5": typeStr = getLocalizedString("mod. in cloud turbulence (frequent)");
				break;
			case "6": typeStr = getLocalizedString("severe clear air turbulence (occasional)");
				break;
			case "7": typeStr = getLocalizedString("severe clear air turbulence (frequent)");
				break;
			case "8": typeStr = getLocalizedString("severe in cloud turbulence (occasional)");
				break;
			case "9": typeStr = getLocalizedString("severe in cloud turbulence (frequent)");
				break;
			case "X": typeStr = getLocalizedString("extreme turbulence");
				break;
		}
		if (metricFormat <= 3) {
			var heightStr = getLocalizedString("at base") + " " +  (parseInt(elemStr.substr(2,3),10) * 100) + " " + getLocalizedString("feet");
			var thickStr = getLocalizedString("thickness") + " " + (parseInt(elemStr.substr(5,1),10) * 1000) + " " + getLocalizedString("feet");
		}
		else {
			var heightStr = getLocalizedString("at base") + " " + Math.round((parseInt(elemStr.substr(2,3),10) * 100) * 0.3048 / 10) * 10 + " " + getLocalizedString("meter");
			var thickStr = getLocalizedString("thickness") + " " + Math.round((parseInt(elemStr.substr(5,1),10) * 1000) * 0.3048 / 10) * 10 + " " + getLocalizedString("meter");
		}
	}

	if (elemStr.substr(0,1) == "6") {
		var groupStr = getLocalizedString("Icing:");
		var typeStr = "";
		var tmpStr = elemStr.substr(1,1);
		switch (tmpStr) {
			case "0": typeStr = getLocalizedString("no icing");
				break;
			case "1": typeStr = getLocalizedString("light icing (mixed)");
				break;
			case "2": typeStr = getLocalizedString("light icing in cloud (rime)");
				break;
			case "3": typeStr = getLocalizedString("light icing in precipation (clear)");
				break;
			case "4": typeStr = getLocalizedString("moderate icing (mixed)");
				break;
			case "5": typeStr = getLocalizedString("moderate icing in cloud (rime)");
				break;
			case "6": typeStr = getLocalizedString("moderate icing in precipitation (clear)");
				break;
			case "7": typeStr = getLocalizedString("severe icing (mixed)");
				break;
			case "8": typeStr = getLocalizedString("severe icing in cloud (rime)");
				break;
			case "9": typeStr = getLocalizedString("severe icing in precipitaion (clear)");
				break;
		}
		if (metricFormat <= 3) {
			var heightStr = getLocalizedString("at base") + " " +  (parseInt(elemStr.substr(2,3),10) * 100) + " " + getLocalizedString("feet");
			var thickStr = getLocalizedString("thickness") + " " + (parseInt(elemStr.substr(5,1),10) * 1000) + " " + getLocalizedString("feet");
		}
		else {
			var heightStr = getLocalizedString("at base") + " " + Math.round((parseInt(elemStr.substr(2,3),10) * 100) * 0.3048 / 10) * 10 + " " + getLocalizedString("meter");
			var thickStr = getLocalizedString("thickness") + " " + Math.round((parseInt(elemStr.substr(5,1),10) * 1000) * 0.3048 / 10) * 10 + " " + getLocalizedString("meter");
		}
	}
	
	var returnStr = "<tr valign='top'><td>" + groupStr + "</td><td>" + typeStr + " " + heightStr + ", " + thickStr + "</td></tr>";
	return returnStr;
}



function parseTemperature(elemStr,obj)
{
	var tmppos = elemStr.indexOf("/");
	var tmpStr1 = elemStr.substring(0,tmppos);
	var tmpStr2 = elemStr.substring(tmppos+1,elemStr.length);

	if (tmpStr1.charAt(0) == "M")
		var temp = parseInt(tmpStr1.substr(1,2),10) * -1;
	else
		var temp = parseInt(tmpStr1.substr(0,2),10);


	if (tmpStr2.charAt(0) == "M")
		var dew = parseInt(tmpStr2.substr(1,2),10) * -1;
	else
		var dew = parseInt(tmpStr2.substr(0,2),10);

	if (!isNaN(temp) && !isNaN(dew)) {						// relative humidity: use always Celsius to calculate
		var relHumidity =  calculateRelHumidity(temp,dew);
		var relHumidityStr = ", " + getLocalizedString("RH: ") + relHumidity + "%";
	}
	else {
		var relHumidity = "-";
		var relHumidityStr = "";
	}

	if (obj != null) {
		obj.gTemperature = temp;
		obj.gDewpoint = dew;
		obj.gHumidity = relHumidity;
	}

	if (metricFormat == 1) {
		temp = Math.round((1.8 * temp) + 32);
		dew = Math.round((1.8 * dew) + 32);
		if (isNaN(temp))
			temp = "--";
		if (isNaN(dew))
			dew = "--";
		
		var returnStr = "<tr valign='top'><td>" + getLocalizedString("Temperature: ") + "</td><td>" + temp + "&#176;F, " 
						+ getLocalizedString("Dewpoint: ") + dew + "&#176;F" + relHumidityStr + "</td></tr>";
		}
	else {
		if (isNaN(temp))
			temp = "--";
		if (isNaN(dew))
			dew = "--";
					
		var returnStr = "<tr valign='top'><td>" + getLocalizedString("Temperature: ") + "</td><td>" + temp + "&#176;C, " 
						+ getLocalizedString("Dewpoint: ") + dew + "&#176;C" + relHumidityStr + "</td></tr>";
	}
	
	
	return returnStr;
}


function calculateRelHumidity(t,td)
{	
	if (t < 0)
		var sddt = 6.1078 *  Math.pow(10,((7.6 * t) / (240.7 + t)));
	else
		var sddt = 6.1078 *  Math.pow(10,((7.5 * t) / (237.3 + t)));
	
	if (td < 0)
		var sddtd = 6.1078 *  Math.pow(10,((7.6 * td) / (240.7 + td)));
	else
		var sddtd = 6.1078 *  Math.pow(10,((7.5 * td) / (237.3 + td)));

	var rh =  100 * (sddtd / sddt);
	
	
	return roundNumber(rh,0);
}



function parseTemperatureForecast(elemStr,obj)
{
	var dateVal = 0;
	var dateStr = "";

	if (elemStr.charAt(1) == "X" || elemStr.charAt(1) == "N") {		// new format
		var tmppos = elemStr.indexOf ("/");
		var tmpStr1 = elemStr.substring(2,tmppos);
		if (elemStr.length - tmppos <= 4) {
			var timeStr = elemStr.substr(tmppos+1,2) + ":00";
		}
		else {		// new definition of Nov 5th, e.g., TX25/2612Z TN12/2723Z
			dateVal = parseInt(elemStr.substr(tmppos+1,2),10);
			var timeStr = elemStr.substr(tmppos+3,2) + ":00";
		}
		
		if (elemStr.charAt(1) == "X")
			var minmax = getLocalizedString("maximum");
		if (elemStr.charAt(1) == "N")
			var minmax = getLocalizedString("minimum");
	}
	else {															// old format
		var tmppos = elemStr.indexOf ("/");
		var tmpStr1 = elemStr.substring(1,tmppos);
		var minmax = "";
		if (elemStr.length - tmppos <= 4) {
			var timeStr = elemStr.substr(tmppos+1,2) + ":00";
		}
		else {		// new definition of Nov 5th, e.g., T25/2612Z
			dateVal = parseInt(elemStr.substr(tmppos+1,2),10);
			var timeStr = elemStr.substr(tmppos+3,2) + ":00";
		}
	}
	
	if (tmpStr1.charAt(0) == "M")
		var temp = parseInt(tmpStr1.substr(1,2),10) * -1;
	else
		var temp = parseInt(tmpStr1.substr(0,2),10);

	if (showLocalTime && dateVal > 0) {
		dateStr = " (" + adjustLocalTimeDay(dateVal,parseInt(timeStr.substr(0,2),10),obj) + ".)";
	}


	if (metricFormat == 1) {
		temp = Math.round((1.8 * temp) + 32);
		if (showLocalTime)
			var returnStr = "<tr valign='top'><td>" + getLocalizedString("Temperature: ") + "</td><td>" + minmax + " " + temp + "&#176;F " + getLocalizedString("at") + " " + convertUTCtoLocal(timeStr,obj) + dateStr + "</td></tr>";
		else
			var returnStr = "<tr valign='top'><td>" + getLocalizedString("Temperature: ") + "</td><td>" + minmax + " " + temp + "&#176;F " + getLocalizedString("at") + " " + timeStr + " " + getLocalizedString("UTC") + dateStr + "</td></tr>";
	}
	else {
		if (showLocalTime)
			var returnStr = "<tr valign='top'><td>" + getLocalizedString("Temperature: ") + "</td><td>" + minmax + " " + temp + "&#176;C " + getLocalizedString("at") + " " + convertUTCtoLocal(timeStr,obj) + dateStr + "</td></tr>";
		else
			var returnStr = "<tr valign='top'><td>" + getLocalizedString("Temperature: ") + "</td><td>" + minmax + " " + temp + "&#176;C " + getLocalizedString("at") + " " + timeStr + " " + getLocalizedString("UTC") + dateStr + "</td></tr>";
	}
	return returnStr;
}


function parsePressure(elemStr,obj)
{
	if (elemStr.charAt(0) == "Q") {
		var pressure = parseInt(elemStr.substr(1,4),10);
		if (metricFormat <= 2) {
			var tmpStr = String(pressure / 33.8639);
			var pressureStr = tmpStr.substr(0,5) + " inches Hg";
		}
		else
			var pressureStr = pressure + " hPa";
	}
	else {
		var pressure = elemStr.substr(1,2) + "." + elemStr.substr(3,2);
		
		if (metricFormat <= 2)
			var pressureStr = pressure + " inches Hg";
		else {
			pressure = Math.round(pressure * 33.8639);
			var pressureStr = pressure + " hPa";
		}
	}
	
	if (obj != null) {
		obj.gPressure = pressureStr;
	}
	
	var returnStr = "<tr valign='top'><td>" + getLocalizedString("Pressure: ") + "</td><td>" + pressureStr + " " + getPressureTrend() + "</td></tr>";
	return returnStr;
}


function parsePressureForecast(elemStr)
{
	if (elemStr.length == 10) {
		if (metricFormat <= 2) {
			var pressure = elemStr.substr(3,2) + "." + elemStr.substr(5,2);
			var pressureStr = pressure + " inches Hg";
		}
		else {
			var pressure = elemStr.substr(3,2) + "." + elemStr.substr(5,2);
			pressure = Math.round(pressure * 33.8639);
			var pressureStr = pressure + " hPa";
		}
	
		var returnStr = "<tr valign='top'><td>" + getLocalizedString("Pressure: ") + "</td><td>" + pressureStr + "</td></tr>";
	}
	else
		var returnStr = "";
		
	return returnStr;
}


function parseTimePeriod(elemStr,obj)
{
	var tmpTimeFrom = "";
	var tmpTimeTo = "";
	
	if (elemStr.length == 4) {
		tmpTimeFrom = elemStr.substr(0,2) + ":00";
		tmpTimeTo = elemStr.substr(2,2) + ":00";
	}
	
	if (elemStr.length == 6) {
		tmpTimeFrom = elemStr.substr(2,2) + ":00";
		tmpTimeTo = elemStr.substr(4,2) + ":00";
	}
	
	if (showLocalTime)
		var returnStr = convertUTCtoLocal(tmpTimeFrom,obj) + " " + getLocalizedString("to") + " " + convertUTCtoLocal(tmpTimeTo,obj);
	else
		var returnStr = tmpTimeFrom + " " + getLocalizedString("to") + " " + tmpTimeTo + " " + getLocalizedString("UTC");
	
	return returnStr;
}



function parseTimePeriodLong(elemStr,obj)		// format ffff/tttt
{
	var tmpTimeFrom = "";
	var tmpTimeTo = "";
	var dateStr = "";
	var dateVal = 0;

	if (elemStr.length == 9) {
		tmpTimeFrom = elemStr.substr(2,2) + ":00";
		tmpTimeTo = elemStr.substr(7,2) + ":00";
		dateVal = parseInt(elemStr.substr(5,2),10);
		dateStr = " (" + elemStr.substr(5,2) + ".)";
	}
	
	if (showLocalTime) {
		dateStr = " (" + adjustLocalTimeDay(dateVal,parseInt(tmpTimeTo.substr(0,2),10),obj) + ".)";
		var returnStr = convertUTCtoLocal(tmpTimeFrom,obj) + " " + getLocalizedString("to") + " " + convertUTCtoLocal(tmpTimeTo,obj) + dateStr;
	}
	else
		var returnStr = tmpTimeFrom + " " + getLocalizedString("to") + " " + tmpTimeTo + " " + getLocalizedString("UTC") + dateStr;
	
	return returnStr;
	
	/*
	if (elemStr.length == 9) {
		tmpTimeFrom = elemStr.substr(0,2) + ":" + elemStr.substr(2,2);
		tmpTimeTo = elemStr.substr(5,2) + ":" + elemStr.substr(7,2);
	}
		
	if (showLocalTime)
		var returnStr = convertUTCtoLocal(tmpTimeFrom,obj) + " " + getLocalizedString("to") + " " + convertUTCtoLocal(tmpTimeTo,obj);
	else
		var returnStr = tmpTimeFrom + " " + getLocalizedString("to") + " " + tmpTimeTo + " " + getLocalizedString("UTC");
	
	return returnStr;*/
}


function parseFrom(elemStr,obj)
{
	var tmpTimeFrom = "";
	var dateStr = "";
	var dateVal = 0;

	if (elemStr.length == 7 && elemStr.charAt(6) == "Z") {
		tmpTimeFrom = elemStr.substr(2,2) + ":" + elemStr.substr(4,2);
	}
	
	if (elemStr.length == 6) {
		tmpTimeFrom = elemStr.substr(2,2) + ":" + elemStr.substr(4,2);
	}
	
	if (elemStr.length == 4) {
		tmpTimeFrom = elemStr.substr(2,2) + ":" + "00";
	}
	
	if (elemStr.length == 8) {			// new TAF of Nov 5th
		tmpTimeFrom = elemStr.substr(4,2) + ":" + elemStr.substr(6,2);
		dateStr = " (" + elemStr.substr(2,2) + ".)";
		dateVal = parseInt(elemStr.substr(2,2),10);
	}

	if (showLocalTime) {
		if (dateVal > 0)
			dateStr = " (" + adjustLocalTimeDay(dateVal,parseInt(tmpTimeFrom.substr(0,2),10),obj) + ".)";
		var returnStr = getLocalizedString("from") + " " + convertUTCtoLocal(tmpTimeFrom,obj) + dateStr;
	}
	else
		var returnStr = getLocalizedString("from") + " " + tmpTimeFrom + " " +  getLocalizedString("UTC") + dateStr;

	return returnStr;
}


function parseUntil(elemStr,obj)
{
	var tmpTimeFrom = "";
	
	if (elemStr.length == 6) {
		tmpTimeFrom = elemStr.substr(2,2) + ":" + elemStr.substr(4,2);
	}
	else
		return "";

	if (showLocalTime)
		var returnStr = getLocalizedString("until") + " " + convertUTCtoLocal(tmpTimeFrom,obj);
	else
		var returnStr = getLocalizedString("until") + " " + tmpTimeFrom + " " +  getLocalizedString("UTC");

	return returnStr;
}



function parseRMK(elemStr)
{
	var remarks = "";
	
	for (j = elemStr + 1; j < metarArray.length; j++)
		remarks = remarks + metarArray[j] + " ";

	var returnStr = "<tr valign='top'><td>" + getLocalizedString("Remarks:") + "</td><td>" + remarks + "</td></tr>";
	return returnStr;
}


function parseColorCode(elemStr)
{
	var colortext = elemStr;
	switch (elemStr) {
		case "BLU":	colortext = "<span style='color:skyblue'>" + elemStr + "</span>";	break;
		case "GRN":	colortext = "<span style='color:limegreen'>" + elemStr + "</span>";	break;
		case "YLO":	colortext = "<span style='color:yellow'>" + elemStr + "</span>";	break;
		case "AMB":	colortext = "<span style='color:#FFBF00'>" + elemStr + "</span>";	break;
		case "RED":	colortext = "<span style='color:red'>" + elemStr + "</span>";	break;
		default:	;	// WHT
	}

	var returnStr = "<tr valign='top'><td>" + getLocalizedString("Mil-Code: ") + "</td><td>" + colortext + "</td></tr>";
	return returnStr;
}




function parseMetarString(metarStrOrig,obj,isMetar)
{
		var afterMain = false;
		var afterTempo = false;
		var finished = false;
		var tmppos2 = 0;
		var tmppos3 = 0;
		var isTempo = false;
		var isBecmg = false;
		var isFrom = false;
		var isProb = false;
		var isForecast = true;
		var prevWeather = false;
		var metarStr = "";
		
		metarArray = new Array();

		if (metarStr == "NIL" || metarStr == "CLR") {
			metarTxt = "NIL";
			return;
		}

//		test strings
//		metarStrOrig = "301128Z 3012/0118 14005KT P6SM SCT025 OVC040 TEMPO 3012/3016 OVC025 FM302200 13015G23KT P6SM OVC015 FM312100 13015G22KT P6SM OVC008 BECMG 3021/0101 1SM -SN FM010100 09015KT 3SM BR OVC006 TEMPO 0101/0105 2SM -SN BLSN FM011500 01015KT 5SM BR OVC006=";
//		if (!isMetar)
//			metarStrOrig = "261000Z 2612/2718 34010KT 9999 SCT040 BECMG 2612/2621 530007 VRB15G45KT TN24/2612Z T25/2623Z T30/10Z TX31/10Z FM302200 SCT050 R01L/0800FT R01R/M0800N WS R14 PROB30 TEMPO 2613/2618 5000NW SHUP WS RWY16 BECMG 2620/2622 WS ALL RWY CAVOK FM270900 27008KT 9999 SCT040 PROB30 2713/2718 5000 TSRA TX25/2612ZTN12/2723Z=";
		for (var i = 0; i < metarStrOrig.length; i++) {							// replace cr's with blanks !!!!
			if (metarStrOrig.charCodeAt(i) == 10)
				metarStr = metarStr + " ";
			else
				metarStr = metarStr + metarStrOrig.charAt(i);
		}
	

		var tmppos2 = 0;
		var tmppos = metarStr.indexOf(" ");
		if (tmppos == -1)
			return 3;

		metarArray[0] = metarStr.substring(0,tmppos);
		var i = 1;
		while (true) {
			tmppos2 = tmppos+1;
			tmppos = metarStr.indexOf(" ",tmppos2);
			if (tmppos == -1) {
				metarArray[i] = metarStr.substring(tmppos2,metarStr.length);
				i++;
				break;
			}			
			metarArray[i] = metarStr.substring(tmppos2,tmppos);
			i++;
		}		
				
		for (i = 0; i < metarArray.length; i++) {

			if (metarArray[i].indexOf("NIL") >= 0) {
				metarTxt = metarTxt + "<tr valign='top'><td colspan='2'>" + getLocalizedString("No Data Available.") + " (NIL)" + "</td> ";
				continue;
			}
			
			if (metarArray[i].indexOf("CNL") >= 0) {
				metarTxt = metarTxt + "<tr valign='top'><td colspan='2'>" + getLocalizedString("Cancelled.") + " (CNL)" + "</td> ";
				continue;
			}
		
			if (metarArray[i].indexOf("COR") >= 0) {
				continue;
			}

			if (metarArray[i].indexOf("TEMP") >= 0) {
				metarTxt = metarTxt + "<tr valign='top'><td class='label'>" + getLocalizedString("TEMPORARY") + "</td> ";
				afterTempo = true;
				isTempo = true;
				prevWeather = false;
				continue;
			}

			if (metarArray[i].indexOf("BECMG") >= 0) {
				metarTxt = metarTxt + "<tr valign='top'><td class='label'>" + getLocalizedString("BECOMING") + "</td> ";
				afterTempo = true;
				isBecmg = true;
				prevWeather = false;
				continue;
			}

			if (metarArray[i].indexOf("INTER") >= 0) {
				metarTxt = metarTxt + "<tr valign='top'><td colspan='2' class='label'>" + getLocalizedString("Intermittent");
				if (metarArray[i+1].charCodeAt(0) >= 48 && metarArray[i+1].charCodeAt(0) <= 57 && metarArray[i+1].length == 4 && metarArray[i+1].charCodeAt(1) != 48 && metarArray[i+1].charCodeAt(2) != 48) {
					metarTxt = metarTxt + " " + getLocalizedString("from") + " " + parseTimePeriod(metarArray[i+1],obj) + ":</td></tr>";
					i++;
				}
				else
					if (metarArray[i+1].indexOf("/") >= 0 &&  metarArray[i+1].length == 9) {
						metarTxt = metarTxt + " " + getLocalizedString("from") + " " + parseTimePeriodLong(metarArray[i+1],obj) + ":</td></tr>";
						i++;
					}
					else
						metarTxt = metarTxt + ":</td> </tr>";
				continue;
			}


			if (metarArray[i].indexOf("PROB") >= 0) {
				if (metarArray[i].charCodeAt(4) >= 48 && metarArray[i].charCodeAt(4) <= 57)
					metarTxt = metarTxt + "<tr valign='top'><td class='label'>" + getLocalizedString("PROBABILITY") + " " + metarArray[i].substr(4,2)  + "% " + "</td>";
				else
					metarTxt = metarTxt + "<tr valign='top'><td class='label'>" + getLocalizedString("PROBABILITY") + " " + metarArray[i].substr(5,2)  + "% " + "</td>";
					
				if (metarArray[i+1].charCodeAt(0) >= 48 && metarArray[i+1].charCodeAt(0) <= 57 && metarArray[i+1].length == 4 && metarArray[i+1].charCodeAt(2) != 48 && metarArray[i+1].charCodeAt(3) != 48) {
					metarTxt = metarTxt + "<td class='timeSpan'>" + parseTimePeriod(metarArray[i+1],obj) + "</td></tr>";
					i++;
				}
				else
					metarTxt = metarTxt + "</tr>";

				afterTempo = true;
				prevWeather = false;
//				isProb = false;
				continue;
			}

			if (metarArray[i].indexOf("RMK") >= 0) {
				if (showRMK)
					metarTxt = metarTxt + parseRMK(i);
				break;
			}

			if (metarArray[i].length == 3 && (metarArray[i].indexOf("BLU") >= 0 || metarArray[i].indexOf("WHT") >= 0 || metarArray[i].indexOf("GRN") >= 0 ||
				metarArray[i].indexOf("YLO") >= 0 || metarArray[i].indexOf("AMB") >= 0 || metarArray[i].indexOf("RED") >= 0)) {
					metarTxt = metarTxt + parseColorCode(metarArray[i]);
					continue;
			}

			if (metarArray[i].indexOf("AUTO") >= 0) {
				continue;

			}
			
			if (metarArray[i].indexOf("NOSIG") >= 0) {
				metarTxt = metarTxt + "<tr valign='top'><td colspan='2'>" + getLocalizedString("No significant changes.") + "</td></tr>";
				continue;
			}


			if (metarArray[i].indexOf("RE") >= 0) {
				metarTxt = metarTxt + parseRecent(metarArray[i]);
				continue;
			}

			if (metarArray[i].indexOf("FM") >= 0) {
				metarTxt = metarTxt + "<tr valign='top'><td colspan='2' class='timeSpan'>" + parseFrom(metarArray[i],obj) + ": " + "</td></tr>";
				isFrom = true;
				prevWeather = false;
				continue;
			}

			if (metarArray[i].indexOf("TL") >= 0) {
				metarTxt = metarTxt + "<tr valign='top'><td colspan='2' class='timeSpan'>" + parseUntil(metarArray[i],obj) + ": " + "</td></tr>";
//				isFrom = true;
				continue;
			}


			if (metarArray[i].charCodeAt(0) >= 48 && metarArray[i].charCodeAt(0) <= 57 && (metarArray[i].length >= 5 && metarArray[i].length <= 7) && 
				(metarArray[i].charAt(4) == "N" || metarArray[i].charAt(4) == "E" || metarArray[i].charAt(4) == "S" || metarArray[i].charAt(4) == "W" || metarArray[i].indexOf("NDV") >= 0))  {
				metarTxt = metarTxt + parseVisibilty3(metarArray[i]);
				continue;
			}
			

			if (metarArray[i].charCodeAt(0) >= 48 && metarArray[i].charCodeAt(0) <= 52 && metarArray[i].length == 6  && metarArray[i].indexOf("/") == -1) {
				metarTxt = metarTxt + "<tr valign='top'><td class='labelForecast'>" + getLocalizedString("Forecast: ") + "</td><td class='timeSpan'>" + parseTimePeriod(metarArray[i],obj) + "</td></tr>";
				isForecast = false;
				continue;
			}
			
			
			if (metarArray[i].charCodeAt(0) >= 48 && metarArray[i].charCodeAt(0) <= 57 && metarArray[i].indexOf("/") >= 0 && metarArray[i].length == 9 && metarArray[i].charAt(0) != "R") {			// time period FFFF/TTTT

					if (isTempo || isBecmg) {
						metarTxt = metarTxt + "<td class='timeSpan'>" + parseTimePeriodLong(metarArray[i],obj) + "</td></tr>";
						isTempo = false;
					}
					if (isForecast && !isMetar) {
						metarTxt = metarTxt + "<tr valign='top'><td class='labelForecast'>" + getLocalizedString("Forecast: ") + "</td><td class='timeSpan'>" + parseTimePeriodLong(metarArray[i],obj) + "</td></tr>";
						isForecast = false;
					}

//				metarTxt = metarTxt + parseTimePeriodLong(metarArray[i],obj);
				continue;
			}


			if (metarArray[i].indexOf("CAVOK") >= 0 || metarArray[i].indexOf("KM") >= 0 || metarArray[i].indexOf("SM") >= 0) {
				metarTxt = metarTxt + parseVisibilty2(metarArray[i],null);
				extraSM = false;
				continue;
			}


			if (metarArray[i].charCodeAt(0) >= 48 && metarArray[i].charCodeAt(0) <= 57 && metarArray[i].length == 4 && afterTempo) {
				if ((metarArray[i].charCodeAt(2) == 48 && metarArray[i].charCodeAt(3) == 48) || (metarArray[i].charCodeAt(2) == 57 && metarArray[i].charCodeAt(3) == 57))	// if last two digits = 0 or last 2digit = 99 it's probably visibility instead
					metarTxt = metarTxt + parseVisibilty(metarArray[i],null);
				else {
					if (isTempo)
						metarTxt = metarTxt + "<td class='timeSpan'>" + parseTimePeriod(metarArray[i],obj) + "</td></tr>";
					if (isBecmg)
						metarTxt = metarTxt + "<td class='timeSpan'>" + parseTimePeriod(metarArray[i],obj) + "</td></tr>";
//					if (isProb)
//						metarTxt = metarTxt + "<td class='timeSpan'>" + parseTimePeriod(metarArray[i],obj) + "</td></tr>";
					afterTempo = false;
					isTempo = false;
					isBecmg = false;
//					isProb = false;
				}
				continue;
			}
			

			if (metarArray[i].charCodeAt(0) >= 48 && metarArray[i].charCodeAt(0) <= 57 && metarArray[i].length == 1 && !afterTempo) {
				extraSMVal = metarArray[i].charAt(0);
				extraSM = true;
				continue;
			}


			if (metarArray[i].charCodeAt(0) >= 48 && metarArray[i].charCodeAt(0) <= 57 && metarArray[i].length == 1) {
				metarTxt = metarTxt + parseVisibilty2(metarArray[i],null);
				continue;
			}


			if (metarArray[i].charCodeAt(0) >= 48 && metarArray[i].charCodeAt(0) <= 57 && metarArray[i].length == 3 && afterTempo) {
				if (metarArray[i].indexOf("SM") >= 0)
					metarTxt = metarTxt + parseVisibilty2(metarArray[i],null);
				else
					if (metarArray[i].charCodeAt(0) > 50)		// if first number > 2 it's probably visibility (meter) instead
						metarTxt = metarTxt + parseVisibilty(metarArray[i],null);
				continue;
			}

			
			if ((metarArray[i].indexOf("KT") >= 0 || metarArray[i].indexOf("MPS") >= 0) && metarArray[i].indexOf("WS") < 0) {		// wind
				metarTxt = metarTxt + parseWind(metarArray[i],null) + " ";
				if (i+1 < metarArray.length)
					if (metarArray[i+1].charAt(3) == "V") {
						metarTxt = metarTxt + parseVariableWind(metarArray[i+1],null);
						i++;
					}
				continue;
			}
	
			if (metarArray[i].charCodeAt(0) >= 48 && metarArray[i].charCodeAt(0) <= 57 && metarArray[i].length == 4 && !afterTempo) {
				if (i <= 1 && !isMetar) {  // in this case it might be forecast time and not visibility
					metarTxt = metarTxt + "<tr valign='top'><td class='labelForecast'>" + getLocalizedString("Forecast: ") + "</td><td class='timeSpan'>" + parseTimePeriod(metarArray[i],obj) + "</td></tr>";
					isForecast = false;
				}
				else 
					metarTxt = metarTxt + parseVisibilty(metarArray[i],null);
				continue;
			}

			if (metarArray[i].indexOf("NCD") >= 0) {
				metarTxt = metarTxt + "<tr valign='top'><td>" + getLocalizedString("Clouds: ") + "</td><td>" + getLocalizedString("no clouds detected") + "</td></tr>";
				continue;
			}
			
			if (metarArray[i].indexOf("SCT") >= 0 || metarArray[i].indexOf("FEW") >= 0 || metarArray[i].indexOf("BKN") >= 0 || metarArray[i].indexOf("OVC") >= 0) {
				metarTxt = metarTxt + "<tr valign='top'><td>" + getLocalizedString("Clouds: ") + "</td><td>";
				metarTxt = metarTxt + parseClouds(metarArray[i]);

				if (i+1 < metarArray.length) {
					if ((metarArray[i+1].indexOf("SCT") >= 0 || metarArray[i+1].indexOf("FEW") >= 0 || metarArray[i+1].indexOf("BKN") >= 0 || metarArray[i+1].indexOf("OVC") >= 0)) {
						metarTxt = metarTxt +  "<br id='tbr'>" + parseClouds(metarArray[i+1]);
						i++;
						
						if (i+1 < metarArray.length) {
							if ((metarArray[i+1].indexOf("SCT") >= 0 || metarArray[i+1].indexOf("FEW") >= 0 || metarArray[i+1].indexOf("BKN") >= 0 || metarArray[i+1].indexOf("OVC") >= 0)) {
								metarTxt = metarTxt +  "<br id='tbr'>" + parseClouds(metarArray[i+1]);
								i++;

								if (i+1 < metarArray.length) {
									if ((metarArray[i+1].indexOf("SCT") >= 0 || metarArray[i+1].indexOf("FEW") >= 0 || metarArray[i+1].indexOf("BKN") >= 0 || metarArray[i+1].indexOf("OVC") >= 0)) {
										metarTxt = metarTxt +  "<br id='tbr'>" + parseClouds(metarArray[i+1]) + "</td></tr>";
										i++;
										continue;
									}
									else {
										metarTxt = metarTxt +  "</td></tr>";
										continue;
									}
								}
								else {
									metarTxt = metarTxt +  "</td></tr>";
									continue;
								}
							}
							else {
								metarTxt = metarTxt +  "</td></tr>";
								continue;
							}
						}
						else {
							metarTxt = metarTxt +  "</td></tr>";
							continue;
						}
					}
					else {
						metarTxt = metarTxt +  "</td></tr>";
						continue;
					}
				}
				else {
					metarTxt = metarTxt +  "</td></tr>";
					continue;				
				}
			}

			if (metarArray[i].indexOf("WS") >= 0 && metarArray[i].length == 2) {			// Windshear on runways
				if (i+1 < metarArray.length) {
					if (metarArray[i+1].charAt(0) == "R") {
						metarTxt = metarTxt + parseWindshearRwy(metarArray[i+1]);
						i++;
						continue;
					}
					else
					if (metarArray[i+1].charAt(0) == "A") {
						i++;
						if (i+1 < metarArray.length) {
							if (metarArray[i+1].charAt(0) == "R") {
								metarTxt = metarTxt + parseWindshearRwy("ALL RWY");
								i++;
								continue;
							}
						}
					}
				}
				continue;
			}

			if (metarArray[i].indexOf("WS") >= 0 && metarArray[i].length > 4) {				// Windshear
				metarTxt = metarTxt + parseWindshear(metarArray[i]);
				continue;
			}

			if (metarArray[i].charCodeAt(0) >= 48 && metarArray[i].charCodeAt(0) <= 57 && metarArray[i].length == 8) {				// Runway Report
				metarTxt = metarTxt + parseRunwayReport(metarArray[i]);
				continue;
			}

			if (metarArray[i].indexOf("VV") >= 0 || metarArray[i].indexOf("CLR") >= 0 || metarArray[i].indexOf("SKC") >= 0) {
				metarTxt = metarTxt + "<tr valign='top'><td></td><td>" + parseClouds2(metarArray[i]) + "</td></tr>";
				continue;
			}

			if (metarArray[i].indexOf("NSW") >= 0) {
				metarTxt = metarTxt + "<tr valign='top'><td>" + getLocalizedString("Weather: ") + "</td><td>" + getLocalizedString("No significant weather") + "</td></tr>";
				continue;
			}

			if (metarArray[i].indexOf("NSC") >= 0) {
				metarTxt = metarTxt + "<tr valign='top'><td>" + getLocalizedString("Clouds: ") + "</td><td>" + getLocalizedString("No significant clouds") + "</td></tr>";
				continue;
			}

			if ((metarArray[i].charAt(0) == "Q" || metarArray[i].charAt(0) == "A") && (metarArray[i].length == 4 || metarArray[i].length == 5)) {
				metarTxt = metarTxt + parsePressure(metarArray[i],obj);
				continue;
			}

			if (metarArray[i].indexOf("QNH") >= 0 && metarArray[i].indexOf("INS") >= 0) {
				metarTxt = metarTxt + parsePressureForecast(metarArray[i]);
				continue;
			}
			
			if (metarArray[i].charAt(0) == "R" && metarArray[i].indexOf("/") >= 0) {				// Runway RVR
				metarTxt = metarTxt + parseTrendRVR(metarArray[i]);
				continue;
			}

			if ((metarArray[i].charAt(0) == "5" || metarArray[i].charAt(0) == "6") && metarArray[i].length == 6) {				// Icing & Turbulence
				metarTxt = metarTxt + parseIcingTurbulence(metarArray[i]);
				continue;
			}
			

			if (metarArray[i].indexOf("/") >= 0 && metarArray[i].charAt(0) == "T") {				// check temp forecast first 
				var secondTemp = metarArray[i].lastIndexOf("T");
				if (secondTemp >= 4)	{								// second forecast is in same string // TX25/2612ZTN12/2723Z
					metarTxt = metarTxt + parseTemperatureForecast(metarArray[i].substring(0,secondTemp),obj);
				
					var tmpStr = metarArray[i].substring(secondTemp,metarArray[i].length);
					metarTxt = metarTxt + parseTemperatureForecast(tmpStr,obj);
				}
				else
					metarTxt = metarTxt + parseTemperatureForecast(metarArray[i],obj);
				continue;
			}
			
			if (metarArray[i].indexOf("/") >= 0 && (metarArray[i].charAt(0) == "M" || (metarArray[i].charCodeAt(0) >= 48 && metarArray[i].charCodeAt(0) <= 57))) {
				metarTxt = metarTxt + parseTemperature(metarArray[i],obj);
				continue;
			}

			if ((metarArray[i].charCodeAt(0) >= 65 || metarArray[i].charAt(0) == "-" || metarArray[i].charAt(0) == "+") && metarArray[i].length <= 8 && metarArray[i].indexOf("/") == -1) {
				if (!prevWeather) {
					metarTxt = metarTxt + "<tr valign='top'><td>" + getLocalizedString("Weather: ") + "</td><td>" + parseWeather(metarArray[i],null) + "</td></tr>";
					prevWeather = true;
				}
				else {
					metarTxt = metarTxt.substr(0,metarTxt.length - 10);
					metarTxt = metarTxt + "; " + parseWeather(metarArray[i],null) + "</td></tr>";
					prevWeather = false;
				}
				continue;
			}

			if (metarArray[i].indexOf("//") == 0) {
				continue;
			}


		}

}


function parsePressureOnly(metarstr)
{
	var tmpstr = metarstr.substring(metarstr.indexOf(" ")+1,metarstr.length)

	var limit = tmpstr.length;

	var trend = tmpstr.indexOf("BECMG");					// omit trend data
	if (trend > 0)
		limit = trend;
	var trend = tmpstr.indexOf("TEMPO");
	if (trend > 0 && trend < limit)
		limit = trend;
	var trend = tmpstr.indexOf("FM");
	if (trend > 0 && trend < limit)
		limit = trend;
	var trend = tmpstr.indexOf("INTER");
	if (trend > 0 && trend < limit)
		limit = trend;
	var trend = tmpstr.indexOf("RMK");
	if (trend > 0 && trend < limit)
		limit = trend;

	var mstr = tmpstr.substring(0,limit);

	if (mstr.length < 12)
		return 0;
	
	var tmpPressure = mstr.indexOf(" Q");
	if (tmpPressure >= 0) {
		var pressure = parseInt(mstr.substr(tmpPressure+2,4),10);
		return pressure;
	}
	
	var tmpPressure = mstr.indexOf(" A");
	if (tmpPressure >= 0) {
		var pressure = mstr.substr(tmpPressure+2,2) + "." + mstr.substr(tmpPressure+4,2);
		pressure = Math.round(pressure * 33.8639);
		return pressure;
	}
	
	return 0;
}



function parseFlightRules(metarstr)
{
	var tmpstr = metarstr.substring(metarstr.indexOf(" ")+1,metarstr.length);
	var limit = tmpstr.length;

	var trend = tmpstr.indexOf("BECMG");					// omit trend data for flight condition evaluation
	if (trend > 0)
		limit = trend;
	var trend = tmpstr.indexOf("TEMPO");
	if (trend > 0 && trend < limit)
		limit = trend;
	var trend = tmpstr.indexOf("FM");
	if (trend > 0 && trend < limit)
		limit = trend;
	var trend = tmpstr.indexOf("INTER");
	if (trend > 0 && trend < limit)
		limit = trend;
	var trend = tmpstr.indexOf("RMK");
	if (trend > 0 && trend < limit)
		limit = trend;

	var mstr = tmpstr.substring(0,limit);

	if (mstr.length < 12)
		return "";


	var ceiling = 0;
	if (mstr.indexOf("CAVOK") >= 0 || mstr.indexOf("CLR ") >= 0 || mstr.indexOf("SKC") >= 0 || mstr.indexOf("NSC") >= 0 || mstr.indexOf("NCD") >= 0) {
		ceiling = 5000;
	}
	else {
		ceiling = 5000;
		var bkn = mstr.indexOf("BKN");
		if (bkn >= 0)
			ceiling = parseInt(mstr.substr(bkn+3,3),10) * 100;
			
		var ovc = mstr.indexOf("OVC");
		if (ovc >= 0) {
			var ovcCeiling = parseInt(mstr.substr(ovc+3,3),10) * 100;
			if (ovcCeiling < ceiling)
				ceiling = ovcCeiling;
		}
	}
	

	var visibility = 0;
	if (mstr.indexOf("9999") >= 0 || mstr.indexOf("10SM") >= 0) {
		visibility = 6;
	}
	else {
		var tmp = mstr.indexOf("SM ");
		if (tmp > 0) {
			var tmp3 = mstr.indexOf("/");
			if (tmp3 > 0 && tmp3 < tmp) {
				var miles = parseInt(mstr.substr(tmp3-1,1),10) / parseInt(mstr.substr(tmp3+1,1),10);
				visibility = miles;
				if (mstr.charAt(tmp3-2) == " " && mstr.charAt(tmp3-4) == " ") {
					var sm = mstr.charCodeAt(tmp3-3);
					if (sm >= 48 && sm <= 57) {
						visibility = visibility + parseInt(mstr.charAt(tmp3-3),10);
					}
				}
			}
			else {
				var tmp2 = mstr.lastIndexOf(" ",tmp);
				var miles = parseInt(mstr.substring(tmp2+1,tmp),10);
				visibility = miles;
			}
		}
		else {
			var tmp = mstr.indexOf("KT ");
			if (tmp > 0) {
				if (mstr.charAt(tmp + 6) == "V")
					tmp = tmp + 10;
				
				var tmp2 = mstr.indexOf("0 ",tmp);
				if (mstr.charAt(tmp2-4) == " ") {
					visibility = parseInt(mstr.substr(tmp2-3,4),10) / 1.609344 / 1000;
				}
				else {
					visibility = 6;
				}
			}
			else {
				var tmp = mstr.indexOf("MPS ");
				if (tmp > 0) {
					if (mstr.charAt(tmp + 7) == "V")
						tmp = tmp + 11;
						
					var tmp2 = mstr.indexOf("0 ",tmp);
					if (mstr.charAt(tmp2-4) == " ") {
						visibility = parseInt(mstr.substr(tmp2-3,4),10) / 1.609344 / 1000;
					}
					else {
						visibility = 6;
					}
				}
				else {
					visibility = 6;
				}
			}
		}
	}

	if (ceiling < 500 || visibility < 1)
		return "LIFR";
	else
		if ((ceiling >= 500 && ceiling < 1000) || (visibility >= 1 && visibility < 3))
			return "IFR";
		else
			if ((ceiling >= 1000 && ceiling < 3000) || (visibility >= 3 && visibility < 5))
				return "MVFR";
			else
				if (ceiling >= 3000 && visibility >= 5)
					return "VFR";
				else
					return "";
}



function parseMetarGraphical(metarstr,obj)
{
	if (obj == null)		
		return false;

	var tmpstr = metarstr.substring(metarstr.indexOf(" ")+1,metarstr.length)

	var limit = tmpstr.length;

	var trend = tmpstr.indexOf("BECMG");					// omit trend data for graphical display
	if (trend > 0)
		limit = trend;
	var trend = tmpstr.indexOf("TEMPO");
	if (trend > 0 && trend < limit)
		limit = trend;
	var trend = tmpstr.indexOf("FM");
	if (trend > 0 && trend < limit)
		limit = trend;
	var trend = tmpstr.indexOf("INTER");
	if (trend > 0 && trend < limit)
		limit = trend;
	var trend = tmpstr.indexOf("RMK");
	if (trend > 0 && trend < limit)
		limit = trend;

	var mstr = tmpstr.substring(0,limit);
	
	if (mstr.length < 12)
		return false;
	
	var graphMetarArray = new Array();
	var prevWeather = false;

	
	var tmppos2 = 0;
	var tmppos = mstr.indexOf(" ");
	if (tmppos == -1)
		return 3;

	graphMetarArray[0] = mstr.substring(0,tmppos);
	var i = 1;
	while (true) {
		tmppos2 = tmppos+1;
		tmppos = mstr.indexOf(" ",tmppos2);
		if (tmppos == -1) {
			graphMetarArray[i] = mstr.substring(tmppos2,mstr.length);
			i++;
			break;
		}			
		graphMetarArray[i] = mstr.substring(tmppos2,tmppos);
		i++;
	}

				
	for (i = 0; i < graphMetarArray.length; i++) {

		if (graphMetarArray[i].indexOf("NOSIG") >= 0) {
			continue;
		}

		if (graphMetarArray[i].indexOf("RETS") >= 0) {
			continue;
		}


		if ((graphMetarArray[i].indexOf("KT") >= 0 || graphMetarArray[i].indexOf("MPS") >= 0) && graphMetarArray[i].indexOf("WS") < 0) {		// wind
			parseWind(graphMetarArray[i],obj);
			if (i+1 < graphMetarArray.length)
				if (graphMetarArray[i+1].charAt(3) == "V") {
					parseVariableWind(graphMetarArray[i+1],obj);
					i++;
				}
			continue;
		}

		if (graphMetarArray[i].indexOf("KM") >= 0 || graphMetarArray[i].indexOf("SM") >= 0) {
			parseVisibilty2(graphMetarArray[i],obj);
			continue;
		}

		if (graphMetarArray[i].charCodeAt(0) >= 48 && graphMetarArray[i].charCodeAt(0) <= 57 && graphMetarArray[i].length == 4) {
			parseVisibilty(graphMetarArray[i],obj);
			continue;
		}
		
		if (graphMetarArray[i].indexOf("CAVOK") >= 0) {
			obj.gVisibility = 10000;
			continue;
		}

		if (graphMetarArray[i].indexOf("SCT") >= 0 || graphMetarArray[i].indexOf("FEW") >= 0 || graphMetarArray[i].indexOf("BKN") >= 0 || graphMetarArray[i].indexOf("OVC") >= 0) {
			obj.gCloud1 = graphMetarArray[i];

			if (i+1 < graphMetarArray.length) {
				if ((graphMetarArray[i+1].indexOf("SCT") >= 0 || graphMetarArray[i+1].indexOf("FEW") >= 0 || graphMetarArray[i+1].indexOf("BKN") >= 0 || graphMetarArray[i+1].indexOf("OVC") >= 0)) {
					obj.gCloud2 = graphMetarArray[i+1];
					i++;
						
					if (i+1 < graphMetarArray.length)
						if ((graphMetarArray[i+1].indexOf("SCT") >= 0 || graphMetarArray[i+1].indexOf("FEW") >= 0 || graphMetarArray[i+1].indexOf("BKN") >= 0 || graphMetarArray[i+1].indexOf("OVC") >= 0)) {
							obj.gCloud3 = graphMetarArray[i+1];
							i++;

							if (i+1 < graphMetarArray.length)
								if ((graphMetarArray[i+1].indexOf("SCT") >= 0 || graphMetarArray[i+1].indexOf("FEW") >= 0 || graphMetarArray[i+1].indexOf("BKN") >= 0 || graphMetarArray[i+1].indexOf("OVC") >= 0)) {
									i++;
									continue;
								}
							else
								continue;
						}
						else
							continue;
				}
				else
					continue;
			}
			else
				continue;				
		}

		if ((graphMetarArray[i].charAt(0) == "Q" || graphMetarArray[i].charAt(0) == "A") && (graphMetarArray[i].length == 4 || graphMetarArray[i].length == 5)) {
			parsePressure(graphMetarArray[i],obj);
			
			continue;
		}


		if (graphMetarArray[i].indexOf("/") >= 0 && (graphMetarArray[i].charAt(0) == "M" || (graphMetarArray[i].charCodeAt(0) >= 48 && graphMetarArray[i].charCodeAt(0) <= 57))) {
			parseTemperature(graphMetarArray[i],obj);
			continue;
		}

		if ((graphMetarArray[i].charCodeAt(0) >= 65 || graphMetarArray[i].charAt(0) == "-" || graphMetarArray[i].charAt(0) == "+") && graphMetarArray[i].length <= 8 && graphMetarArray[i].indexOf("/") == -1) {
			parseWeather(graphMetarArray[i],obj);
			continue;
		}

	}
		
	return true;
}